@@ -7,8 +7,8 @@
  *     Christian Schulte, 2004
  *
  *  Last modified:
- *     $Date: 2009-05-06 16:12:12 +0200 (Wed, 06 May 2009) $ by $Author: schulte $
- *     $Revision: 9006 $
+ *     $Date: 2009-10-16 10:09:14 +0200 (Fri, 16 Oct 2009) $ by $Author: schulte $
+ *     $Revision: 9935 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -325,7 +325,8 @@ public:
   enum {
     BRANCH_DEGREE,      ///< Choose variable with largest degree
     BRANCH_SIZE,        ///< Choose variable with smallest size
-    BRANCH_SIZE_DEGREE  ///< Choose variable with smallest size/degree
+    BRANCH_SIZE_DEGREE, ///< Choose variable with smallest size/degree
+    BRANCH_SIZE_AFC,    ///< Choose variable with smallest size/degree
   };
   /// The actual model
   GraphColor(const SizeOptions& opt)
@@ -348,16 +349,23 @@ public:
       if (opt.model() == MODEL_CLIQUE)
         rel(*this, m, IRT_GQ, n-1);
     }
-    IntVarArgs ma(1);
-    ma[0] = m;
-    branch(*this, ma, INT_VAR_NONE, INT_VAL_MIN);
-    if (opt.branching() == BRANCH_SIZE) {
+    branch(*this, m, INT_VAL_MIN);
+    switch (opt.branching()) {
+    case BRANCH_SIZE:
       branch(*this, v, INT_VAR_SIZE_MIN, INT_VAL_MIN);
-    } else if (opt.branching() == BRANCH_DEGREE) {
+      break;
+    case BRANCH_DEGREE:
       branch(*this, v, tiebreak(INT_VAR_DEGREE_MAX,INT_VAR_SIZE_MIN),
              INT_VAL_MIN);
-    } else {
+      break;
+    case BRANCH_SIZE_DEGREE:
       branch(*this, v, INT_VAR_SIZE_DEGREE_MIN, INT_VAL_MIN);
+      break;
+    case BRANCH_SIZE_AFC:
+      branch(*this, v, INT_VAR_SIZE_AFC_MIN, INT_VAL_MIN);
+      break;
+    default:
+      break;
     }
   }
   /// Cost function
@@ -407,6 +415,7 @@ main(int argc, char* argv[]) {
   opt.branching(GraphColor::BRANCH_DEGREE, "degree");
   opt.branching(GraphColor::BRANCH_SIZE, "size");
   opt.branching(GraphColor::BRANCH_SIZE_DEGREE, "sizedegree");
+  opt.branching(GraphColor::BRANCH_SIZE_AFC, "sizeafc");
   opt.parse(argc,argv);
   Script::run<GraphColor,BAB,SizeOptions>(opt);
   return 0;
