@@ -11,8 +11,8 @@
  *     Mikael Lagerkivst, 2007
  *
  *  Last modified:
- *     $Date: 2009-05-14 00:24:31 +0200 (Thu, 14 May 2009) $ by $Author: tack $
- *     $Revision: 9095 $
+ *     $Date: 2009-09-08 21:10:29 +0200 (Tue, 08 Sep 2009) $ by $Author: schulte $
+ *     $Revision: 9692 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -367,7 +367,7 @@ namespace {
     &k5[0], &k6[0], &k7[0], &k8[0], &k9[0]
   };
   /// Number of examples
-  const unsigned int n_examples = sizeof(examples)/sizeof(char*);
+  const unsigned int n_examples = sizeof(examples)/sizeof(const int*);
 
 
   /** \brief Class for solutions of a distinct-linear constraint problem.
@@ -399,12 +399,12 @@ namespace {
    *
    * \relates Kakuro
    */
-  template <class C> C generate(int n, int c);
+  template<class C> C generate(int n, int c);
 
   /** \brief Generate DFA for \a n distinct variables with sum \a c
    * \relates Kakuro
    */
-  template <>
+  template<>
   DFA generate<DFA>(int n, int c) {
     // Setup search engine that enumerates all solutions
     DistinctLinear* e = new DistinctLinear(n,c);
@@ -444,7 +444,7 @@ namespace {
   /** \brief Generate tuple set for \a n distinct variables with sum \a c
    * \relates Kakuro
    */
-  template <>
+  template<>
   TupleSet generate<TupleSet>(int n, int c) {
     // Setup search engine that enumerates all solutions
     DistinctLinear* e = new DistinctLinear(n,c);
@@ -464,7 +464,7 @@ namespace {
   /** \brief Class to remember already computed specifications of type Data
    * \relates Kakuro
    */
-  template <class Data>
+  template<class Data>
   class Cache {
   private:
     class Entry {
@@ -544,7 +544,7 @@ public:
       b(x,y).init(*this,1,9);
   }
   /// Post a distinct-linear constraint on variables \a x with sum \a c
-  template <class Data>
+  template<class Data>
   void distinctlinear(Cache<Data>& dc, const IntVarArgs& x, int c,
                       const SizeOptions& opt) {
     if (opt.model() == MODEL_DECOMPOSE) {
