@@ -1,14 +1,16 @@
 /* -*- mode: C++; c-basic-offset: 2; indent-tabs-mode: nil -*- */
 /*
  *  Main authors:
+ *     Mikael Lagerkvist <lagerkvist@gecode.org>
  *     Christian Schulte <schulte@gecode.org>
  *
  *  Copyright:
+ *     Mikael Lagerkvist, 2008
  *     Christian Schulte, 2001
  *
  *  Last modified:
- *     $Date: 2009-04-02 20:58:46 +0200 (Thu, 02 Apr 2009) $ by $Author: schulte $
- *     $Revision: 8649 $
+ *     $Date: 2009-10-07 11:13:58 +0200 (Wed, 07 Oct 2009) $ by $Author: tack $
+ *     $Revision: 9848 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -38,9 +40,104 @@
 #include <gecode/driver.hh>
 #include <gecode/int.hh>
 #include <gecode/minimodel.hh>
+#include <gecode/graph.hh>
 
 using namespace Gecode;
 
+
+/** \brief Custom brancher for knights tours using Warnsdorff's rule
+ *
+ * This class implements Warnsdorff's rule for finding Knights
+ * tours. The next position is choosen by taking the jump that
+ * minimizes the number of alternatives in the next step.
+ *
+ * \relates Knights
+ */
+class Warnsdorff : public Brancher {
+protected:
+  /// Views of the brancher
+  ViewArray<Int::IntView> x;
+  /// Next variable to branch on
+  mutable int start;
+  /// Choice
+  class Choice : public Gecode::Choice {
+  public:
+    /// Position of variable
+    int pos;
+    /// Value of variable
+    int val;
+    /** Initialize choice for brancher \a b, position \a pos0, 
+     *  and value \a val0.
+     */
+    Choice(const Brancher& b, int pos0, int val0)
+      : Gecode::Choice(b,2), pos(pos0), val(val0) {}
+    /// Report size occupied
+    virtual size_t size(void) const {
+      return sizeof(Choice);
+    }
+  };
+ 
+  /// Construct brancher
+  Warnsdorff(Space& home, ViewArray<Int::IntView>& xv) 
+    : Brancher(home), x(xv), start(0) {}
+  /// Copy constructor
+  Warnsdorff(Space& home, bool share, Warnsdorff& b) 
+    : Brancher(home, share, b), start(b.start) {
+    x.update(home, share, b.x);
+  }
+public:
+  /// Check status of brancher, return true if alternatives left
+  virtual bool status(const Space&) const {
+    // Follow path of assigned variables
+    while (true) {
+      if (!x[start].assigned()) 
+        return true;
+      start = x[start].val();
+      if (start == 0) 
+        return false;
+    }
+  }
+  /// Return choice
+  virtual Gecode::Choice* choice(Space&) {
+    Int::ViewValues<Int::IntView> iv(x[start]);
+    int n = iv.val();
+    unsigned int min = x[n].size();
+    ++iv;
+    // Choose the value with the fewest neighbours
+    while (iv()) {
+      if (x[iv.val()].size() < min) {
+        n = iv.val();
+        min = x[n].size();
+      }
+      ++iv;
+    }
+    return new Choice(*this, start, n);
+  }
+  /// Perform commit for choice \a _c and alternative \a a
+  virtual ExecStatus commit(Space& home, const Gecode::Choice& _c, 
+                            unsigned int a) {
+    const Choice& c = static_cast<const Choice&>(_c);
+    if (a == 0)
+      return me_failed(x[c.pos].eq(home, c.val)) ? ES_FAILED : ES_OK;
+    else 
+      return me_failed(x[c.pos].nq(home, c.val)) ? ES_FAILED : ES_OK;
+  }
+  /// Copy brancher
+  virtual Actor* copy(Space& home, bool share) {
+    return new (home) Warnsdorff(home, share, *this);
+  }
+  /// Post brancher
+  static void post(Space& home, const IntVarArgs& x) {
+    ViewArray<Int::IntView> xv(home, x);
+    (void) new (home) Warnsdorff(home, xv);
+  }
+  /// Delete brancher and return its size
+  virtual size_t dispose(Space&) {
+    return sizeof(*this);
+  }
+};
+
+
 /// Base-class for Knights tour example
 class Knights : public Script {
 protected:
@@ -54,6 +151,11 @@ public:
     PROP_REIFIED, ///< Use reified constraints
     PROP_CIRCUIT  ///< Use single circuit constraints
   };
+  /// Branching to use for model
+  enum {
+    BRANCH_NAIVE,      ///< Use naive, lexicographical branching
+    BRANCH_WARNSDORFF, ///< Use Warnsdorff's rule
+  };
   /// Return field at position \a x, \a y
   int
   field(int x, int y) const {
@@ -77,7 +179,16 @@ public:
   }
   /// Constructor
   Knights(const SizeOptions& opt)
-    : n(opt.size()), succ(*this,n*n,0,n*n-1) {}
+    : n(opt.size()), succ(*this,n*n,0,n*n-1) {
+    switch (opt.branching()) {
+    case BRANCH_NAIVE:
+      branch(*this, succ, INT_VAR_NONE, INT_VAL_MIN);
+      break;
+    case BRANCH_WARNSDORFF:
+      Warnsdorff::post(*this, succ);
+      break;
+    }
+  }
   /// Constructor for cloning \a s
   Knights(bool share, Knights& s) : Script(share,s), n(s.n) {
     succ.update(*this, share, s.succ);
@@ -152,7 +263,6 @@ public:
       dom(*this, succ[f], ds);
       rel(*this, succ[f], IRT_NQ, pred[f]);
     }
-    branch(*this, succ, INT_VAR_NONE, INT_VAL_MIN);
   }
   /// Constructor for cloning \a s
   KnightsReified(bool share, KnightsReified& s) : Knights(share,s) {}
@@ -188,7 +298,6 @@ public:
       IntSet ds(nbs, n_nbs);
       dom(*this, succ[f], ds);
     }
-    branch(*this, succ, INT_VAR_NONE, INT_VAL_MIN);
   }
   /// Constructor for cloning \a s
   KnightsCircuit(bool share, KnightsCircuit& s) : Knights(share,s) {}
@@ -210,6 +319,9 @@ main(int argc, char* argv[]) {
   opt.propagation(Knights::PROP_CIRCUIT);
   opt.propagation(Knights::PROP_REIFIED, "reified");
   opt.propagation(Knights::PROP_CIRCUIT, "circuit");
+  opt.branching(Knights::BRANCH_NAIVE);
+  opt.branching(Knights::BRANCH_NAIVE, "reified");
+  opt.branching(Knights::BRANCH_WARNSDORFF, "warnsdorff");
   opt.parse(argc,argv);
   if (opt.propagation() == Knights::PROP_REIFIED) {
     Script::run<KnightsReified,DFS,SizeOptions>(opt);
