@@ -11,8 +11,8 @@
  *     Mikael Lagerkvist, 2009
  *
  *  Last modified:
- *     $Date: 2009-05-14 00:24:31 +0200 (Thu, 14 May 2009) $ by $Author: tack $
- *     $Revision: 9095 $
+ *     $Date: 2009-08-26 20:56:42 +0200 (Wed, 26 Aug 2009) $ by $Author: schulte $
+ *     $Revision: 9631 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -47,6 +47,7 @@ using namespace Gecode;
 
 /// Instance data for radio therapy problem
 class RadiotherapyData {
+private:
   /// Compute incremental sum
   int incr_sum(int row) {
     int sum = intensity[row*n];
@@ -203,9 +204,9 @@ public:
   }
 
   /// Nested search on the q variables
-  class NestedSearch : public Branching {
+  class NestedSearch : public Brancher {
   private:
-    /// Flag that the branching is done after one commit
+    /// Flag that the brancher is done after one commit
     bool done;
     /// Mapping of index to weight
     struct Idx { 
@@ -216,21 +217,21 @@ public:
     };
     /// Weighted ordering of rows
     SharedArray<Idx> index;
-    /// Description that only signals failure or success
-    class Description : public BranchingDesc {
+    /// Choice that only signals failure or success
+    class Choice : public Gecode::Choice {
     public:
-      /// Whether branching should fail
+      /// Whether brancher should fail
       bool fail;
-      /// Initialize description for branching \a b
-      Description(const Branching& b, bool fail0)
-      : BranchingDesc(b,1), fail(fail0) {}
+      /// Initialize choice for brancher \a b
+      Choice(const Brancher& b, bool fail0)
+      : Gecode::Choice(b,1), fail(fail0) {}
       /// Report size occupied
       virtual size_t size(void) const {
-        return sizeof(Description);
+        return sizeof(Choice);
       }
     };
-    /// Construct branching
-    NestedSearch(Space& home) : Branching(home), done(false) {
+    /// Construct brancher
+    NestedSearch(Space& home) : Brancher(home), done(false) {
       Radiotherapy& rt = static_cast<Radiotherapy&>(home);
       // Set up ordering of rows.  As a heuristic, pre-order the rows
       // with the potentially cheapest ones first.
@@ -250,7 +251,7 @@ public:
     }
     /// Copy constructor
     NestedSearch(Space& home, bool share, NestedSearch& b)
-      : Branching(home, share, b), done(b.done) {
+      : Brancher(home, share, b), done(b.done) {
       index.update(home, share, b.index);
     }
   public:
@@ -269,7 +270,7 @@ public:
       return ri;
     }
 
-    virtual BranchingDesc* description(Space& home) {
+    virtual Gecode::Choice* choice(Space& home) {
       done = true;
       Radiotherapy& rt = static_cast<Radiotherapy&>(home);
 
@@ -299,16 +300,16 @@ public:
         }      
       }
 
-      return new Description(*this, fail);
+      return new Choice(*this, fail);
     }
-    virtual ExecStatus commit(Space&, const BranchingDesc& d, unsigned int) {
-      return static_cast<const Description&>(d).fail ? ES_FAILED : ES_OK;
+    virtual ExecStatus commit(Space&, const Gecode::Choice& _c, unsigned int) {
+      return static_cast<const Choice&>(_c).fail ? ES_FAILED : ES_OK;
     }
-    /// Copy branching
+    /// Copy brancher
     virtual Actor* copy(Space& home, bool share) {
       return new (home) NestedSearch(home, share, *this);
     }
-    /// Post branching
+    /// Post brancher
     static void post(Space& home) {
       (void) new (home) NestedSearch(home);
     }
@@ -321,7 +322,7 @@ public:
         for (int i = index.size()-1; i--; )
           index[i].weight *= 0.9;
       }
-      (void) Branching::dispose(home);
+      (void) Brancher::dispose(home);
       (void) index.~SharedArray<Idx>();
       return sizeof(*this);
     }
