@@ -7,8 +7,8 @@
  *     Mikael Lagerkvist, 2008
  *
  *  Last modified:
- *     $Date: 2009-05-14 19:35:46 +0200 (Thu, 14 May 2009) $ by $Author: tack $
- *     $Revision: 9118 $
+ *     $Date: 2009-08-26 20:56:42 +0200 (Wed, 26 Aug 2009) $ by $Author: schulte $
+ *     $Revision: 9631 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -171,8 +171,8 @@ protected:
 public:
   /// Branching variants
   enum {
-    BRANCHING_NAIVE,   ///< Simple branching
-    BRANCHING_SYMMETRY ///< Breaking symmetries with branching
+    SYMMETRY_NONE,   ///< Simple symmetry
+    SYMMETRY_BRANCHING ///< Breaking symmetries with symmetry
   };
 
   /// Actual model
@@ -252,10 +252,10 @@ public:
     linear(*this, slabcost, IRT_EQ, total_cost);
 
     // Add branching
-    if (opt.branching() == BRANCHING_SYMMETRY) {
+    if (opt.symmetry() == SYMMETRY_BRANCHING) {
       // Install custom branching
       SteelMillBranch::post(*this);
-    } else { // opt.branching() == BRANCHING_NAIVE
+    } else { // opt.symmetry() == SYMMETRY_NONE
       branch(*this, slab, INT_VAR_MAX_MIN, INT_VAL_MIN);
     }
   }
@@ -308,45 +308,46 @@ public:
   }
 
 
-  /** \brief Custom branching for steel mill slab design
+  /** \brief Custom brancher for steel mill slab design
    *
-   * This class implements a custom branching for SteelMill that
+   * This class implements a custom brancher for SteelMill that
    * considers all slabs with no order assigned to it currently to be
    * symmetric.
    *
    * \relates SteelMill
    */
-  class SteelMillBranch : Branching {
+  class SteelMillBranch : Brancher {
+  protected:
     /// Cache of first unassigned value
     mutable int start;
-    /// Branching description
-    class Description : public BranchingDesc {
+    /// Choice
+    class Choice : public Gecode::Choice {
     public:
       /// Position of variable
       int pos;
       /// Value of variable
       int val;
-      /** Initialize description for branching \a b, number of
+      /** Initialize choice for brancher \a b, number of
        *  alternatives \a a, position \a pos0, and value \a val0.
        */
-      Description(const Branching& b, unsigned int a, int pos0, int val0)
-        : BranchingDesc(b,a), pos(pos0), val(val0) {}
+      Choice(const Brancher& b, unsigned int a, int pos0, int val0)
+        : Gecode::Choice(b,a), pos(pos0), val(val0) {}
       /// Report size occupied
       virtual size_t size(void) const {
-        return sizeof(Description);
+        return sizeof(Choice);
       }
     };
 
-    /// Construct branching
+    /// Construct brancher
     SteelMillBranch(Space& home)
-      : Branching(home), start(0) {}
+      : Brancher(home), start(0) {}
     /// Copy constructor
     SteelMillBranch(Space& home, bool share, SteelMillBranch& b)
-      : Branching(home, share, b), start(b.start) {
+      : Brancher(home, share, b), start(b.start) {
     }
 
   public:
-    /// Check status of branching, return true if alternatives left.
+    /// Check status of brancher, return true if alternatives left.
     virtual bool status(const Space& home) const {
       const SteelMill& sm = static_cast<const SteelMill&>(home);
       for (unsigned int i = start; i < sm.norders; ++i)
@@ -357,8 +358,8 @@ public:
       // No non-assigned orders left
       return false;
     }
-    /// Return branching description
-    virtual BranchingDesc* description(Space& home) {
+    /// Return choice
+    virtual Gecode::Choice* choice(Space& home) {
       SteelMill& sm = static_cast<SteelMill&>(home);
       assert(!sm.slab[start].assigned());
       // Find order with a) minimum size, b) largest weight
@@ -385,29 +386,32 @@ public:
         ++firstzero;
       assert(pos < sm.nslabs &&
              val < sm.norders);
-      return new Description(*this, val<firstzero ? 2 : 1, pos, val);
+      return new Choice(*this, (val<firstzero) ? 2 : 1, pos, val);
     }
-    /// Perform commit for branching description \a d and alternative \a a.
-    virtual ExecStatus commit(Space& home, const BranchingDesc& d,
+    /// Perform commit for choice \a _c and alternative \a a
+    virtual ExecStatus commit(Space& home, const Gecode::Choice& _c,
                               unsigned int a) {
       SteelMill& sm = static_cast<SteelMill&>(home);
-      const Description& desc =
-        static_cast<const Description&>(d);
+      const Choice& c = static_cast<const Choice&>(_c);
       if (a)
-        return me_failed(Int::IntView(sm.slab[desc.pos]).nq(home, desc.val))
+        return me_failed(Int::IntView(sm.slab[c.pos]).nq(home, c.val))
           ? ES_FAILED : ES_OK;
       else
-        return me_failed(Int::IntView(sm.slab[desc.pos]).eq(home, desc.val))
+        return me_failed(Int::IntView(sm.slab[c.pos]).eq(home, c.val))
           ? ES_FAILED : ES_OK;
     }
-    /// Copy branching
+    /// Copy brancher
     virtual Actor* copy(Space& home, bool share) {
       return new (home) SteelMillBranch(home, share, *this);
     }
-    /// Post branching
+    /// Post brancher
     static void post(Space& home) {
       (void) new (home) SteelMillBranch(home);
     }
+    /// Delete brancher and return its size
+    virtual size_t dispose(Space& home) {
+      return sizeof(*this);
+    }
   };
 };
 
@@ -417,9 +421,9 @@ public:
 int
 main(int argc, char* argv[]) {
   SteelMillOptions opt("Steel Mill Slab design");
-  opt.branching(SteelMill::BRANCHING_SYMMETRY);
-  opt.branching(SteelMill::BRANCHING_NAIVE,"naive");
-  opt.branching(SteelMill::BRANCHING_SYMMETRY,"symmetry");
+  opt.symmetry(SteelMill::SYMMETRY_BRANCHING);
+  opt.symmetry(SteelMill::SYMMETRY_NONE,"none");
+  opt.symmetry(SteelMill::SYMMETRY_BRANCHING,"branching");
   opt.solutions(0);
   if (!opt.parse(argc,argv))
     return 1;
