@@ -6,9 +6,12 @@
  *  Copyright:
  *     Christian Schulte, 2007
  *
+ *  Bugfixes provided by:
+ *     Geoffrey Chu
+ *
  *  Last modified:
- *     $Date: 2009-05-14 00:24:31 +0200 (Thu, 14 May 2009) $ by $Author: tack $
- *     $Revision: 9095 $
+ *     $Date: 2009-09-14 21:25:10 +0200 (Mon, 14 Sep 2009) $ by $Author: schulte $
+ *     $Revision: 9741 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -38,6 +41,7 @@
 #include <gecode/driver.hh>
 #include <gecode/int.hh>
 #include <gecode/minimodel.hh>
+#include <gecode/graph.hh>
 
 #include <algorithm>
 
@@ -177,6 +181,8 @@ namespace {
     int size(void) const;
     /// Return distance between node \a i and \a j
     int d(int i, int j) const;
+    /// Return distances
+    const int* d(void) const;
     /// Return estimate for maximal cost of a path
     int max(void) const;
   };
@@ -192,6 +198,10 @@ namespace {
   Problem::d(int i, int j) const {
     return _d[i*_n+j];
   }
+  inline const int*
+  Problem::d(void) const {
+    return _d;
+  }
   inline int
   Problem::max(void) const {
     int m=0;
@@ -233,32 +243,32 @@ public:
     : p(ps[opt.size()]),
       succ(*this, p.size(), 0, p.size()-1),
       total(*this, 0, p.max()) {
+    int n = p.size();
+
+    // Cost matrix
+    IntArgs c(n*n, p.d());
+
+    for (int i=n; i--; )
+      for (int j=n; j--; )
+        if (p.d(i,j) == 0)
+          rel(*this, succ[i], IRT_NQ, j);
 
     // Cost of each edge
-    IntVarArgs costs(p.size());
-    // Distances
-    IntArgs d(p.size());
+    IntVarArgs costs(n);
 
-    // Setup costs for edges
-    for (int i=p.size(); i--; ) {
-      int m=0;
-      for (int j=p.size(); j--; ) {
-        m = std::max(m,p.d(i,j));
-        d[j]=p.d(i,j);
-      }
-      costs[i].init(*this,0,m);
-      // Propagate cost for chosen edge
-      element(*this, d, succ[i], costs[i]);
-    }
+    // Initialize cost variables for edges
+    for (int i=n; i--; )
+      costs[i].init(*this, Int::Limits::min, Int::Limits::max);
 
-    // Cost ist sume of all costs
-    linear(*this, costs, IRT_EQ, total);
-
-    // Enforce that the succesors yield a tour
-    circuit(*this, succ, opt.icl());
+    // Enforce that the succesors yield a tour with appropriate costs
+    circuit(*this, c, succ, costs, total, opt.icl());
 
     // Just assume that the circle starts forwards
-    rel(*this, succ[0], IRT_LE, succ[1]);
+    {
+      IntVar p0(*this, 0, n-1);
+      element(*this, succ, p0, 0);
+      rel(*this, p0, IRT_LE, succ[0]);
+    }
 
     // First enumerate cost values, prefer those that maximize cost reduction
     branch(*this, costs, INT_VAR_REGRET_MAX_MAX, INT_VAL_SPLIT_MIN);
