@@ -7,8 +7,8 @@
  *     Christian Schulte, 2004
  *
  *  Last modified:
- *     $Date: 2009-05-14 04:16:05 +0200 (Thu, 14 May 2009) $ by $Author: tack $
- *     $Revision: 9102 $
+ *     $Date: 2009-10-13 15:19:20 +0200 (Tue, 13 Oct 2009) $ by $Author: schulte $
+ *     $Revision: 9887 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -38,8 +38,6 @@
 
 #include <gecode/driver.hh>
 
-#include <gecode/support/thread.hh>
-
 #include <iostream>
 #include <iomanip>
 
@@ -50,12 +48,40 @@ namespace Gecode {
 
   namespace Driver {
 
+    /*
+     * Option baseclass
+     *
+     */
+    char*
+    BaseOption::strdup(const char* s) {
+      if (s == NULL)
+        return NULL;
+      char* d = heap.alloc<char>(static_cast<unsigned long int>(strlen(s)+1));
+      (void) strcpy(d,s);
+      return d;
+    }
+
+    void
+    BaseOption::strdel(const char* s) {
+      if (s == NULL)
+        return;
+      heap.rfree(const_cast<char*>(s));
+    }
+
+    BaseOption::BaseOption(const char* o, const char* e)
+      : opt(strdup(o)), exp(strdup(e)) {}
+
+    BaseOption::~BaseOption(void) {
+      strdel(opt);
+      strdel(exp);
+    }
+
     void
     StringOption::add(int v, const char* o, const char* h) {
       Value* n = new Value;
       n->val  = v;
-      n->opt  = o;
-      n->help = h;
+      n->opt  = strdup(o);
+      n->help = strdup(h);
       n->next = NULL;
       if (fst == NULL) {
         fst = n;
@@ -111,6 +137,8 @@ namespace Gecode {
     StringOption::~StringOption(void) {
       Value* v = fst;
       while (v != NULL) {
+        strdel(v->opt);
+        strdel(v->help);
         Value* n = v->next;
         delete v;
         v = n;
@@ -212,7 +240,14 @@ namespace Gecode {
   }
 
   BaseOptions::BaseOptions(const char* n)
-    : fst(NULL), lst(NULL), _name(n) {}
+    : fst(NULL), lst(NULL), 
+      _name(Driver::BaseOption::strdup(n)) {}
+
+  void
+  BaseOptions::name(const char* n) {
+    Driver::BaseOption::strdel(_name);
+    _name = Driver::BaseOption::strdup(n);
+  }
 
   void
   BaseOptions::help(void) {
@@ -263,11 +298,16 @@ namespace Gecode {
     return;
   }
   
+  BaseOptions::~BaseOptions(void) {
+    Driver::BaseOption::strdel(_name);
+  }
+
 
   Options::Options(const char* n)
     : BaseOptions(n),
       
       _model("-model","model variants"),
+      _symmetry("-symmetry","symmetry variants"),
       _propagation("-propagation","propagation variants"),
       _icl("-icl","integer consistency level",ICL_DEF),
       _branching("-branching","branching variants"),
@@ -277,7 +317,7 @@ namespace Gecode {
       _threads("-threads","number of threads (0 = #processing units)",
                Search::Config::threads),
       _c_d("-c-d","recomputation commit distance",Search::Config::c_d),
-      _a_d("-a-d","recomputation adaption distance",Search::Config::a_d),
+      _a_d("-a-d","recomputation adaptation distance",Search::Config::a_d),
       _node("-node","node cutoff (0 = none, solution mode)"),
       _fail("-fail","failure cutoff (0 = none, solution mode)"),
       _time("-time","time (in ms) cutoff (0 = none, solution mode)"),
@@ -295,7 +335,8 @@ namespace Gecode {
     _mode.add(SM_STAT, "stat");
     _mode.add(SM_GIST, "gist");
     
-    add(_model); add(_propagation); add(_icl); add(_branching);
+    add(_model); add(_symmetry); add(_propagation); add(_icl); 
+    add(_branching);
     add(_search); add(_solutions); add(_threads); add(_c_d); add(_a_d);
     add(_node); add(_fail); add(_time);
     add(_mode); add(_iterations); add(_samples);
