@@ -7,8 +7,8 @@
  *     Christian Schulte, 2004
  *
  *  Last modified:
- *     $Date: 2009-05-08 20:20:47 +0200 (Fri, 08 May 2009) $ by $Author: schulte $
- *     $Revision: 9046 $
+ *     $Date: 2009-10-13 15:19:20 +0200 (Tue, 13 Oct 2009) $ by $Author: schulte $
+ *     $Revision: 9887 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -36,8 +36,6 @@
  *
  */
 
-#include <gecode/support/timer.hh>
-
 #include <iostream>
 #include <iomanip>
 
@@ -103,12 +101,12 @@ namespace Gecode { namespace Driver {
   /**
    * \brief Traits class for search engines
    */
-  template <class Engine>
+  template<class Engine>
   class GistEngine {
   };
   
   /// Specialization for DFS
-  template <typename S>
+  template<typename S>
   class GistEngine<DFS<S> > {
   public:
     static void explore(S* root, const Gist::Options& opt) {
@@ -117,7 +115,7 @@ namespace Gecode { namespace Driver {
   };
   
   /// Specialization for LDS
-  template <typename S>
+  template<typename S>
   class GistEngine<LDS<S> > {
   public:
     static void explore(S* root, const Gist::Options& opt) {
@@ -126,7 +124,7 @@ namespace Gecode { namespace Driver {
   };
   
   /// Specialization for BAB
-  template <typename S>
+  template<typename S>
   class GistEngine<BAB<S> > {
   public:
     static void explore(S* root, const Gist::Options& opt) {
@@ -135,7 +133,7 @@ namespace Gecode { namespace Driver {
   };
   
   /// Specialization for Restart
-  template <typename S>
+  template<typename S>
   class GistEngine<Restart<S> > {
   public:
     static void explore(S* root, const Gist::Options& opt) {
@@ -145,8 +143,8 @@ namespace Gecode { namespace Driver {
   
 #endif
 
-  template <class Space>
-  template <class Script, template<class> class Engine, class Options>
+  template<class Space>
+  template<class Script, template<class> class Engine, class Options>
   void
   ScriptBase<Space>::run(const Options& o) {
     using namespace std;
@@ -175,7 +173,7 @@ namespace Gecode { namespace Driver {
           t.start();
           Script* s = new Script(o);
           unsigned int n_p = s->propagators();
-          unsigned int n_b = s->branchings();
+          unsigned int n_b = s->branchers();
           Search::Options so;
           so.threads = o.threads();
           so.c_d     = o.c_d();
@@ -193,8 +191,8 @@ namespace Gecode { namespace Driver {
           Search::Statistics stat = e.statistics();
           cout << endl;
           cout << "Initial" << endl
-               << "\tpropagators:  " << n_p << endl
-               << "\tbranchings:   " << n_b << endl
+               << "\tpropagators: " << n_p << endl
+               << "\tbranchers:   " << n_b << endl
                << endl
                << "Summary" << endl
                << "\truntime:      ";
@@ -219,7 +217,7 @@ namespace Gecode { namespace Driver {
           t.start();
           Script* s = new Script(o);
           unsigned int n_p = s->propagators();
-          unsigned int n_b = s->branchings();
+          unsigned int n_b = s->branchers();
           Search::Options so;
           so.clone   = false;
           so.threads = o.threads();
@@ -235,8 +233,8 @@ namespace Gecode { namespace Driver {
           } while (--i != 0);
           Search::Statistics stat = e.statistics();
           cout << endl
-               << "\tpropagators:  " << n_p << endl
-               << "\tbranchings:   " << n_b << endl
+               << "\tpropagators: " << n_p << endl
+               << "\tbranchers:   " << n_b << endl
                << "\truntime:      ";
           stop(t, cout);
           cout << endl
