@@ -7,8 +7,8 @@
  *     Guido Tack, 2006
  *
  *  Last modified:
- *     $Date: 2009-03-24 04:14:40 +0100 (Tue, 24 Mar 2009) $ by $Author: tack $
- *     $Revision: 8522 $
+ *     $Date: 2009-07-30 15:12:16 +0200 (Thu, 30 Jul 2009) $ by $Author: tack $
+ *     $Revision: 9483 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -90,6 +90,7 @@ namespace Gecode { namespace Gist {
     font.setFamily(fontFamily);
     font.setFixedPitch(true);
     font.setPointSize(12);
+    
 
     editor = new QTextEdit;
     editor->setFont(font);
@@ -110,6 +111,18 @@ namespace Gecode { namespace Gist {
     connect(closeWindow, SIGNAL(triggered()), this,
                          SLOT(close()));
 
+    QToolBar* t = addToolBar("Tools");
+    t->setFloatable(false);
+    t->setMovable(false);
+    t->addAction(clearText);
+
+    stayOnTop = new QAction("Stay on top", this);
+    stayOnTop->setCheckable(true);
+    t->addAction(stayOnTop);
+    connect(stayOnTop, SIGNAL(changed()), this,
+                         SLOT(changeStayOnTop()));
+
+    changeStayOnTop();
     setCentralWidget(editor);
     setWindowTitle(QString((std::string("Gist Console: ") + name).c_str()));
 
@@ -133,6 +146,18 @@ namespace Gecode { namespace Gist {
     bf.setBottomMargin(0);
     editor->textCursor().setBlockFormat(bf);
     editor->insertHtml(s);
+    editor->ensureCursorVisible();
+  }
+
+  void TextOutput::changeStayOnTop(void) {
+    QPoint p = pos();
+    if (stayOnTop->isChecked()) {
+      setWindowFlags(windowFlags() | Qt::WindowStaysOnTopHint);
+    } else {
+      setWindowFlags(windowFlags() & ~Qt::WindowStaysOnTopHint);      
+    }
+    move(p);
+    show();
   }
 
 }}
