@@ -9,8 +9,8 @@
  *     Guido Tack, 2006
  *
  *  Last modified:
- *     $Date: 2009-02-03 11:13:22 +0100 (Tue, 03 Feb 2009) $ by $Author: schulte $
- *     $Revision: 8129 $
+ *     $Date: 2009-11-04 17:06:58 +0100 (Wed, 04 Nov 2009) $ by $Author: tack $
+ *     $Revision: 10046 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -41,7 +41,7 @@
 
 namespace Gecode { namespace Int { namespace Arithmetic {
 
-  template <class View, template <class View0,class View1> class Eq>
+  template<class View, template<class View0,class View1> class Eq>
   ExecStatus
   prop_abs_bnd(Space& home, Propagator& p, View x0, View x1) {
     if (x0.assigned()) {
@@ -68,10 +68,10 @@ namespace Gecode { namespace Int { namespace Arithmetic {
     }
 
     if (x0.min() >= 0)
-      GECODE_REWRITE(p,(Eq<View,View>::post(home,x0,x1)));
+      GECODE_REWRITE(p,(Eq<View,View>::post(home(p),x0,x1)));
 
     if (x0.max() <= 0)
-      GECODE_REWRITE(p,(Eq<MinusView,View>::post(home,x0,x1)));
+      GECODE_REWRITE(p,(Eq<MinusView,View>::post(home(p),MinusView(x0),x1)));
 
     GECODE_ME_CHECK(x1.lq(home,std::max(x0.max(),-x0.min())));
     GECODE_ME_CHECK(x0.lq(home,x1.max()));
@@ -79,18 +79,18 @@ namespace Gecode { namespace Int { namespace Arithmetic {
     return ES_NOFIX;
   }
 
-  template <class View>
+  template<class View>
   forceinline
-  AbsBnd<View>::AbsBnd(Space& home, View x0, View x1)
+  AbsBnd<View>::AbsBnd(Home home, View x0, View x1)
     : BinaryPropagator<View,PC_INT_BND>(home,x0,x1) {}
 
-  template <class View>
+  template<class View>
   ExecStatus
-  AbsBnd<View>::post(Space& home, View x0, View x1) {
+  AbsBnd<View>::post(Home home, View x0, View x1) {
     if (x0.min() >= 0) {
       return Rel::EqBnd<View,View>::post(home,x0,x1);
     } else if (x0.max() <= 0) {
-      return Rel::EqBnd<MinusView,View>::post(home,x0,x1);
+      return Rel::EqBnd<MinusView,View>::post(home,MinusView(x0),x1);
     } else {
       assert(!x0.assigned());
       GECODE_ME_CHECK(x1.gq(home,0));
@@ -106,18 +106,18 @@ namespace Gecode { namespace Int { namespace Arithmetic {
     return ES_OK;
   }
 
-  template <class View>
+  template<class View>
   forceinline
   AbsBnd<View>::AbsBnd(Space& home, bool share, AbsBnd<View>& p)
     : BinaryPropagator<View,PC_INT_BND>(home,share,p) {}
 
-  template <class View>
+  template<class View>
   Actor*
   AbsBnd<View>::copy(Space& home,bool share) {
     return new (home) AbsBnd<View>(home,share,*this);
   }
 
-  template <class View>
+  template<class View>
   PropCost
   AbsBnd<View>::cost(const Space&, const ModEventDelta& med) const {
     if (View::me(med) == ME_INT_VAL)
@@ -126,24 +126,24 @@ namespace Gecode { namespace Int { namespace Arithmetic {
       return PropCost::binary(PropCost::LO);
   }
 
-  template <class View>
+  template<class View>
   ExecStatus
   AbsBnd<View>::propagate(Space& home, const ModEventDelta&) {
     return prop_abs_bnd<View,Rel::EqBnd>(home, *this, x0, x1);
   }
 
-  template <class View>
+  template<class View>
   forceinline
-  AbsDom<View>::AbsDom(Space& home, View x0, View x1)
+  AbsDom<View>::AbsDom(Home home, View x0, View x1)
     : BinaryPropagator<View,PC_INT_DOM>(home,x0,x1) {}
 
-  template <class View>
+  template<class View>
   ExecStatus
-  AbsDom<View>::post(Space& home, View x0, View x1) {
+  AbsDom<View>::post(Home home, View x0, View x1) {
     if (x0.min() >= 0) {
       return Rel::EqDom<View,View>::post(home,x0,x1);
     } else if (x0.max() <= 0) {
-      return Rel::EqDom<MinusView,View>::post(home,x0,x1);
+      return Rel::EqDom<MinusView,View>::post(home,MinusView(x0),x1);
     } else {
       assert(!x0.assigned());
       GECODE_ME_CHECK(x1.gq(home,0));
@@ -159,18 +159,18 @@ namespace Gecode { namespace Int { namespace Arithmetic {
     return ES_OK;
   }
 
-  template <class View>
+  template<class View>
   forceinline
   AbsDom<View>::AbsDom(Space& home, bool share, AbsDom<View>& p)
     : BinaryPropagator<View,PC_INT_DOM>(home,share,p) {}
 
-  template <class View>
+  template<class View>
   Actor*
   AbsDom<View>::copy(Space& home,bool share) {
     return new (home) AbsDom<View>(home,share,*this);
   }
 
-  template <class View>
+  template<class View>
   PropCost
   AbsDom<View>::cost(const Space&, const ModEventDelta& med) const {
     if (View::me(med) == ME_INT_VAL)
@@ -180,7 +180,7 @@ namespace Gecode { namespace Int { namespace Arithmetic {
                               PropCost::HI : PropCost::LO);
   }
 
-  template <class View>
+  template<class View>
   ExecStatus
   AbsDom<View>::propagate(Space& home, const ModEventDelta& med) {
     if (View::me(med) != ME_INT_DOM) {
@@ -219,11 +219,11 @@ namespace Gecode { namespace Int { namespace Arithmetic {
       return ES_SUBSUMED(*this,home);
 
     if (x0.min() >= 0)
-      GECODE_REWRITE(*this,(Rel::EqDom<View,View>::post(home,x0,x1)));
+      GECODE_REWRITE(*this,(Rel::EqDom<View,View>::post(home(*this),x0,x1)));
 
     if (x0.max() <= 0) {
       MinusView mx0(x0);
-      GECODE_REWRITE(*this,(Rel::EqDom<MinusView,View>::post(home,mx0,x1)));
+      GECODE_REWRITE(*this,(Rel::EqDom<MinusView,View>::post(home(*this),mx0,x1)));
     }
 
     return ES_FIX;
