@@ -7,8 +7,8 @@
  *     Christian Schulte, 2004
  *
  *  Last modified:
- *     $Date: 2009-02-26 13:32:51 +0100 (Thu, 26 Feb 2009) $ by $Author: schulte $
- *     $Revision: 8303 $
+ *     $Date: 2009-10-14 12:19:49 +0200 (Wed, 14 Oct 2009) $ by $Author: schulte $
+ *     $Revision: 9909 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -44,7 +44,7 @@ namespace Gecode { namespace Int { namespace Arithmetic {
    *
    */
 
-  template <class View>
+  template<class View>
   forceinline ExecStatus
   prop_max_bnd(Space& home, View x0, View x1, View x2) {
     bool mod = false;
@@ -74,14 +74,14 @@ namespace Gecode { namespace Int { namespace Arithmetic {
     return ES_OK;
   }
 
-  template <class View>
+  template<class View>
   forceinline
-  MaxBnd<View>::MaxBnd(Space& home, View x0, View x1, View x2)
+  MaxBnd<View>::MaxBnd(Home home, View x0, View x1, View x2)
     : TernaryPropagator<View,PC_INT_BND>(home,x0,x1,x2) {}
 
-  template <class View>
+  template<class View>
   ExecStatus
-  MaxBnd<View>::post(Space& home, View x0, View x1, View x2) {
+  MaxBnd<View>::post(Home home, View x0, View x1, View x2) {
     GECODE_ME_CHECK(x2.gq(home,std::max(x0.min(),x1.min())));
     GECODE_ME_CHECK(x2.lq(home,std::max(x0.max(),x1.max())));
     if (same(x0,x1))
@@ -94,31 +94,31 @@ namespace Gecode { namespace Int { namespace Arithmetic {
     return ES_OK;
   }
 
-  template <class View>
+  template<class View>
   forceinline
   MaxBnd<View>::MaxBnd(Space& home, bool share, MaxBnd<View>& p)
     : TernaryPropagator<View,PC_INT_BND>(home,share,p) {}
 
-  template <class View>
+  template<class View>
   forceinline
   MaxBnd<View>::MaxBnd(Space& home, bool share, Propagator& p,
                  View x0, View x1, View x2)
     : TernaryPropagator<View,PC_INT_BND>(home,share,p,x0,x1,x2) {}
 
-  template <class View>
+  template<class View>
   Actor*
   MaxBnd<View>::copy(Space& home, bool share) {
     return new (home) MaxBnd<View>(home,share,*this);
   }
 
-  template <class View>
+  template<class View>
   ExecStatus
   MaxBnd<View>::propagate(Space& home, const ModEventDelta&) {
     GECODE_ME_CHECK(prop_max_bnd(home,x0,x1,x2));
     if ((x0.max() <= x1.min()) || (x0.max() < x2.min()))
-      GECODE_REWRITE(*this,(Rel::EqBnd<View,View>::post(home,x1,x2)));
+      GECODE_REWRITE(*this,(Rel::EqBnd<View,View>::post(home(*this),x1,x2)));
     if ((x1.max() <= x0.min()) || (x1.max() < x2.min()))
-      GECODE_REWRITE(*this,(Rel::EqBnd<View,View>::post(home,x0,x2)));
+      GECODE_REWRITE(*this,(Rel::EqBnd<View,View>::post(home(*this),x0,x2)));
     return x0.assigned() && x1.assigned() && x2.assigned() ?
       ES_SUBSUMED(*this,sizeof(*this)) : ES_FIX;
   }
@@ -128,14 +128,14 @@ namespace Gecode { namespace Int { namespace Arithmetic {
    *
    */
 
-  template <class View>
+  template<class View>
   forceinline
-  NaryMaxBnd<View>::NaryMaxBnd(Space& home, ViewArray<View>& x, View y)
+  NaryMaxBnd<View>::NaryMaxBnd(Home home, ViewArray<View>& x, View y)
     : NaryOnePropagator<View,PC_INT_BND>(home,x,y) {}
 
-  template <class View>
+  template<class View>
   ExecStatus
-  NaryMaxBnd<View>::post(Space& home, ViewArray<View>& x, View y) {
+  NaryMaxBnd<View>::post(Home home, ViewArray<View>& x, View y) {
     assert(x.size() > 0);
     x.unique(home);
     if (x.size() == 1)
@@ -160,12 +160,12 @@ namespace Gecode { namespace Int { namespace Arithmetic {
     return ES_OK;
   }
 
-  template <class View>
+  template<class View>
   forceinline
   NaryMaxBnd<View>::NaryMaxBnd(Space& home, bool share, NaryMaxBnd<View>& p)
     : NaryOnePropagator<View,PC_INT_BND>(home,share,p) {}
 
-  template <class View>
+  template<class View>
   Actor*
   NaryMaxBnd<View>::copy(Space& home, bool share) {
     if (x.size() == 1)
@@ -182,7 +182,7 @@ namespace Gecode { namespace Int { namespace Arithmetic {
     MPS_NEW_BOUND = 1<<2  ///< Telling has found a new upper bound
   };
 
-  template <class View>
+  template<class View>
   forceinline ExecStatus
   prop_nary_max_bnd(Space& home, Propagator& p,
                     ViewArray<View>& x, View y, PropCond pc) {
@@ -220,7 +220,7 @@ namespace Gecode { namespace Int { namespace Arithmetic {
     return ((status & MPS_NEW_BOUND) != 0) ? ES_NOFIX : ES_FIX;
   }
 
-  template <class View>
+  template<class View>
   ExecStatus
   NaryMaxBnd<View>::propagate(Space& home, const ModEventDelta&) {
     return prop_nary_max_bnd(home,*this,x,y,PC_INT_BND);
@@ -232,14 +232,14 @@ namespace Gecode { namespace Int { namespace Arithmetic {
    *
    */
 
-  template <class View>
+  template<class View>
   forceinline
-  MaxDom<View>::MaxDom(Space& home, View x0, View x1, View x2)
+  MaxDom<View>::MaxDom(Home home, View x0, View x1, View x2)
     : TernaryPropagator<View,PC_INT_DOM>(home,x0,x1,x2) {}
 
-  template <class View>
+  template<class View>
   ExecStatus
-  MaxDom<View>::post(Space& home, View x0, View x1, View x2) {
+  MaxDom<View>::post(Home home, View x0, View x1, View x2) {
     GECODE_ME_CHECK(x2.gq(home,std::max(x0.min(),x1.min())));
     GECODE_ME_CHECK(x2.lq(home,std::max(x0.max(),x1.max())));
     if (same(x0,x1))
@@ -252,39 +252,39 @@ namespace Gecode { namespace Int { namespace Arithmetic {
     return ES_OK;
   }
 
-  template <class View>
+  template<class View>
   forceinline
   MaxDom<View>::MaxDom(Space& home, bool share, MaxDom<View>& p)
     : TernaryPropagator<View,PC_INT_DOM>(home,share,p) {}
 
-  template <class View>
+  template<class View>
   forceinline
   MaxDom<View>::MaxDom(Space& home, bool share, Propagator& p,
                        View x0, View x1, View x2)
     : TernaryPropagator<View,PC_INT_DOM>(home,share,p,x0,x1,x2) {}
 
-  template <class View>
+  template<class View>
   Actor*
   MaxDom<View>::copy(Space& home, bool share) {
     return new (home) MaxDom<View>(home,share,*this);
   }
 
-  template <class View>
+  template<class View>
   PropCost
   MaxDom<View>::cost(const Space&, const ModEventDelta& med) const {
     return PropCost::ternary((View::me(med) == ME_INT_DOM) ?
                              PropCost::HI : PropCost::LO);
   }
 
-  template <class View>
+  template<class View>
   ExecStatus
   MaxDom<View>::propagate(Space& home, const ModEventDelta& med) {
     if (View::me(med) != ME_INT_DOM) {
       GECODE_ME_CHECK(prop_max_bnd(home,x0,x1,x2));
       if ((x0.max() <= x1.min()) || (x0.max() < x2.min()))
-        GECODE_REWRITE(*this,(Rel::EqDom<View,View>::post(home,x1,x2)));
+        GECODE_REWRITE(*this,(Rel::EqDom<View,View>::post(home(*this),x1,x2)));
       if ((x1.max() <= x0.min()) || (x1.max() < x2.min()))
-        GECODE_REWRITE(*this,(Rel::EqDom<View,View>::post(home,x0,x2)));
+        GECODE_REWRITE(*this,(Rel::EqDom<View,View>::post(home(*this),x0,x2)));
       return x0.assigned() && x1.assigned() && x2.assigned() ?
         ES_SUBSUMED(*this,sizeof(*this)) :
         ES_NOFIX_PARTIAL(*this,View::med(ME_INT_DOM));
@@ -294,11 +294,11 @@ namespace Gecode { namespace Int { namespace Arithmetic {
     GECODE_ME_CHECK(x2.inter_r(home,u,false));
     if (rtest_nq_dom(x0,x2) == RT_TRUE) {
       GECODE_ES_CHECK(Rel::Lq<View>::post(home,x0,x2));
-      GECODE_REWRITE(*this,(Rel::EqDom<View,View>::post(home,x1,x2)));
+      GECODE_REWRITE(*this,(Rel::EqDom<View,View>::post(home(*this),x1,x2)));
     }
     if (rtest_nq_dom(x1,x2) == RT_TRUE) {
       GECODE_ES_CHECK(Rel::Lq<View>::post(home,x1,x2));
-      GECODE_REWRITE(*this,(Rel::EqDom<View,View>::post(home,x0,x2)));
+      GECODE_REWRITE(*this,(Rel::EqDom<View,View>::post(home(*this),x0,x2)));
     }
     return ES_FIX;
   }
@@ -308,14 +308,14 @@ namespace Gecode { namespace Int { namespace Arithmetic {
    *
    */
 
-  template <class View>
+  template<class View>
   forceinline
-  NaryMaxDom<View>::NaryMaxDom(Space& home, ViewArray<View>& x, View y)
+  NaryMaxDom<View>::NaryMaxDom(Home home, ViewArray<View>& x, View y)
     : NaryOnePropagator<View,PC_INT_DOM>(home,x,y) {}
 
-  template <class View>
+  template<class View>
   ExecStatus
-  NaryMaxDom<View>::post(Space& home, ViewArray<View>& x, View y) {
+  NaryMaxDom<View>::post(Home home, ViewArray<View>& x, View y) {
     assert(x.size() > 0);
     x.unique(home);
     if (x.size() == 1)
@@ -340,12 +340,12 @@ namespace Gecode { namespace Int { namespace Arithmetic {
     return ES_OK;
   }
 
-  template <class View>
+  template<class View>
   forceinline
   NaryMaxDom<View>::NaryMaxDom(Space& home, bool share, NaryMaxDom<View>& p)
     : NaryOnePropagator<View,PC_INT_DOM>(home,share,p) {}
 
-  template <class View>
+  template<class View>
   Actor*
   NaryMaxDom<View>::copy(Space& home, bool share) {
     if (x.size() == 1)
@@ -355,7 +355,7 @@ namespace Gecode { namespace Int { namespace Arithmetic {
     return new (home) NaryMaxDom<View>(home,share,*this);
   }
 
-  template <class View>
+  template<class View>
   PropCost
   NaryMaxDom<View>::cost(const Space&, const ModEventDelta& med) const {
     if (View::me(med) == ME_INT_DOM)
@@ -364,7 +364,7 @@ namespace Gecode { namespace Int { namespace Arithmetic {
       return PropCost::linear(PropCost::LO, x.size());
   }
 
-  template <class View>
+  template<class View>
   ExecStatus
   NaryMaxDom<View>::propagate(Space& home, const ModEventDelta& med) {
     if (View::me(med) != ME_INT_DOM) {
@@ -388,7 +388,7 @@ namespace Gecode { namespace Int { namespace Arithmetic {
       }
     assert(x.size() > 0);
     if (x.size() == 1)
-      GECODE_REWRITE(*this,(Rel::EqDom<View,View>::post(home,x[0],y)));
+      GECODE_REWRITE(*this,(Rel::EqDom<View,View>::post(home(*this),x[0],y)));
     return ES_FIX;
   }
 
