@@ -7,8 +7,8 @@
  *     Christian Schulte, 2005
  *
  *  Last modified:
- *     $Date: 2008-08-22 11:36:11 +0200 (Fri, 22 Aug 2008) $ by $Author: tack $
- *     $Revision: 7678 $
+ *     $Date: 2009-09-08 21:10:29 +0200 (Tue, 08 Sep 2009) $ by $Author: schulte $
+ *     $Revision: 9692 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -38,16 +38,16 @@
 namespace Gecode {
 
   /// Traits of IntVarArray
-  template <>
+  template<>
   class ArrayTraits<IntVarArray> {
   public:
-    typedef IntVarArgs   storage_type;
+    typedef IntVarArray  storage_type;
     typedef IntVar       value_type;
     typedef IntVarArgs   args_type;
   };
 
   /// Traits of IntVarArgs
-  template <>
+  template<>
   class ArrayTraits<IntVarArgs> {
   public:
     typedef IntVarArgs storage_type;
@@ -56,7 +56,7 @@ namespace Gecode {
   };
 
   /// Traits of IntArgs
-  template <>
+  template<>
   class ArrayTraits<IntArgs> {
   public:
     typedef IntArgs storage_type;
@@ -64,17 +64,26 @@ namespace Gecode {
     typedef IntArgs args_type;
   };
 
+  /// Traits of IntSetArgs
+  template<>
+  class ArrayTraits<IntSetArgs> {
+  public:
+    typedef IntSetArgs storage_type;
+    typedef IntSet     value_type;
+    typedef IntSetArgs args_type;
+  };
+
   /// Traits of BoolVarArray
-  template <>
+  template<>
   class ArrayTraits<BoolVarArray> {
   public:
-    typedef BoolVarArgs   storage_type;
+    typedef BoolVarArray  storage_type;
     typedef BoolVar       value_type;
     typedef BoolVarArgs   args_type;
   };
 
   /// Traits of BoolVarArgs
-  template <>
+  template<>
   class ArrayTraits<BoolVarArgs> {
   public:
     typedef BoolVarArgs storage_type;
