@@ -7,8 +7,8 @@
  *     Christian Schulte, 2004
  *
  *  Last modified:
- *     $Date: 2009-03-31 01:48:15 +0200 (Tue, 31 Mar 2009) $ by $Author: tack $
- *     $Revision: 8616 $
+ *     $Date: 2009-10-14 12:19:49 +0200 (Wed, 14 Oct 2009) $ by $Author: schulte $
+ *     $Revision: 9909 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -46,10 +46,10 @@ namespace Gecode { namespace Int { namespace Bool {
     /// Constructor for cloning \a p
     OrTrueSubsumed(Space& home, bool share, OrTrueSubsumed& p);
     /// Post propagator
-    static ExecStatus post(Space& home, BV b0, BV b1);
+    static ExecStatus post(Home home, BV b0, BV b1);
   public:
     /// Constructor
-    OrTrueSubsumed(Space& home, BV b0, BV b1);
+    OrTrueSubsumed(Home home, BV b0, BV b1);
     /// Constructor for rewriting \a p during cloning
     OrTrueSubsumed(Space& home, bool share, Propagator& p,
                    BV b0, BV b1);
@@ -59,38 +59,38 @@ namespace Gecode { namespace Int { namespace Bool {
     virtual ExecStatus propagate(Space& home, const ModEventDelta& med);
   };
 
-  template <class BV>
+  template<class BV>
   forceinline
   OrTrueSubsumed<BV>::OrTrueSubsumed
-  (Space& home, BV b0, BV b1)
+  (Home home, BV b0, BV b1)
     : BoolBinary<BV,BV>(home,b0,b1) {}
 
-  template <class BV>
+  template<class BV>
   forceinline ExecStatus
-  OrTrueSubsumed<BV>::post(Space& home, BV b0, BV b1) {
+  OrTrueSubsumed<BV>::post(Home home, BV b0, BV b1) {
     (void) new (home) OrTrueSubsumed(home,b0,b1);
     return ES_OK;
   }
 
-  template <class BV>
+  template<class BV>
   forceinline
   OrTrueSubsumed<BV>::OrTrueSubsumed
   (Space& home, bool share, OrTrueSubsumed<BV>& p)
     : BoolBinary<BV,BV>(home,share,p) {}
 
-  template <class BV>
+  template<class BV>
   forceinline
   OrTrueSubsumed<BV>::OrTrueSubsumed(Space& home, bool share, Propagator& p,
                                      BV b0, BV b1)
     : BoolBinary<BV,BV>(home,share,p,b0,b1) {}
 
-  template <class BV>
+  template<class BV>
   Actor*
   OrTrueSubsumed<BV>::copy(Space& home, bool share) {
     return new (home) OrTrueSubsumed<BV>(home,share,*this);
   }
 
-  template <class BV>
+  template<class BV>
   ExecStatus
   OrTrueSubsumed<BV>::propagate(Space& home, const ModEventDelta&) {
     return ES_SUBSUMED(*this,home);
@@ -102,31 +102,31 @@ namespace Gecode { namespace Int { namespace Bool {
    *
    */
 
-  template <class BVA, class BVB>
+  template<class BVA, class BVB>
   forceinline
-  BinOrTrue<BVA,BVB>::BinOrTrue(Space& home, BVA b0, BVB b1)
+  BinOrTrue<BVA,BVB>::BinOrTrue(Home home, BVA b0, BVB b1)
     : BoolBinary<BVA,BVB>(home,b0,b1) {}
 
-  template <class BVA, class BVB>
+  template<class BVA, class BVB>
   forceinline
   BinOrTrue<BVA,BVB>::BinOrTrue(Space& home, bool share, BinOrTrue<BVA,BVB>& p)
     : BoolBinary<BVA,BVB>(home,share,p) {}
 
-  template <class BVA, class BVB>
+  template<class BVA, class BVB>
   forceinline
   BinOrTrue<BVA,BVB>::BinOrTrue(Space& home, bool share, Propagator& p,
                               BVA b0, BVB b1)
     : BoolBinary<BVA,BVB>(home,share,p,b0,b1) {}
 
-  template <class BVA, class BVB>
+  template<class BVA, class BVB>
   Actor*
   BinOrTrue<BVA,BVB>::copy(Space& home, bool share) {
     return new (home) BinOrTrue<BVA,BVB>(home,share,*this);
   }
 
-  template <class BVA, class BVB>
+  template<class BVA, class BVB>
   inline ExecStatus
-  BinOrTrue<BVA,BVB>::post(Space& home, BVA b0, BVB b1) {
+  BinOrTrue<BVA,BVB>::post(Home home, BVA b0, BVB b1) {
     switch (bool_test(b0,b1)) {
     case BT_SAME:
       GECODE_ME_CHECK(b0.one(home));
@@ -147,7 +147,7 @@ namespace Gecode { namespace Int { namespace Bool {
     return ES_OK;
   }
 
-  template <class BVA, class BVB>
+  template<class BVA, class BVB>
   ExecStatus
   BinOrTrue<BVA,BVB>::propagate(Space& home, const ModEventDelta&) {
 #define GECODE_INT_STATUS(S0,S1) \
@@ -183,9 +183,9 @@ namespace Gecode { namespace Int { namespace Bool {
    *
    */
 
-  template <class BV>
+  template<class BV>
   forceinline
-  TerOrTrue<BV>::TerOrTrue(Space& home, BV b0, BV b1, BV b2)
+  TerOrTrue<BV>::TerOrTrue(Home home, BV b0, BV b1, BV b2)
     : BoolBinary<BV,BV>(home,b0,b1), x2(b2) {}
 
   template<class BV>
@@ -195,14 +195,14 @@ namespace Gecode { namespace Int { namespace Bool {
     return sizeof(*this);
   }
 
-  template <class BV>
+  template<class BV>
   forceinline
   TerOrTrue<BV>::TerOrTrue(Space& home, bool share, TerOrTrue<BV>& p)
     : BoolBinary<BV,BV>(home,share,p) {
     x2.update(home,share,p.x2);
   }
 
-  template <class BV>
+  template<class BV>
   forceinline
   TerOrTrue<BV>::TerOrTrue(Space& home, bool share, Propagator& p,
                            BV b0, BV b1, BV b2)
@@ -210,7 +210,7 @@ namespace Gecode { namespace Int { namespace Bool {
     x2.update(home,share,b2);
   }
 
-  template <class BV>
+  template<class BV>
   Actor*
   TerOrTrue<BV>::copy(Space& home, bool share) {
     assert(x0.none() && x1.none());
@@ -222,14 +222,14 @@ namespace Gecode { namespace Int { namespace Bool {
       return new (home) TerOrTrue<BV>(home,share,*this);
   }
 
-  template <class BV>
+  template<class BV>
   forceinline ExecStatus
-  TerOrTrue<BV>::post(Space& home, BV b0, BV b1, BV b2) {
+  TerOrTrue<BV>::post(Home home, BV b0, BV b1, BV b2) {
     (void) new (home) TerOrTrue<BV>(home,b0,b1,b2);
     return ES_OK;
   }
 
-  template <class BV>
+  template<class BV>
   ExecStatus
   TerOrTrue<BV>::propagate(Space& home, const ModEventDelta&) {
 #define GECODE_INT_STATUS(S0,S1,S2) \
@@ -289,9 +289,9 @@ namespace Gecode { namespace Int { namespace Bool {
    *
    */
 
-  template <class BV>
+  template<class BV>
   forceinline
-  QuadOrTrue<BV>::QuadOrTrue(Space& home, BV b0, BV b1, BV b2, BV b3)
+  QuadOrTrue<BV>::QuadOrTrue(Home home, BV b0, BV b1, BV b2, BV b3)
     : BoolBinary<BV,BV>(home,b0,b1), x2(b2), x3(b3) {}
 
   template<class BV>
@@ -301,7 +301,7 @@ namespace Gecode { namespace Int { namespace Bool {
     return sizeof(*this);
   }
 
-  template <class BV>
+  template<class BV>
   forceinline
   QuadOrTrue<BV>::QuadOrTrue(Space& home, bool share, QuadOrTrue<BV>& p)
     : BoolBinary<BV,BV>(home,share,p) {
@@ -309,7 +309,7 @@ namespace Gecode { namespace Int { namespace Bool {
     x3.update(home,share,p.x3);
   }
 
-  template <class BV>
+  template<class BV>
   forceinline
   QuadOrTrue<BV>::QuadOrTrue(Space& home, bool share, Propagator& p,
                              BV b0, BV b1, BV b2, BV b3)
@@ -318,7 +318,7 @@ namespace Gecode { namespace Int { namespace Bool {
     x3.update(home,share,b3);
   }
 
-  template <class BV>
+  template<class BV>
   Actor*
   QuadOrTrue<BV>::copy(Space& home, bool share) {
     assert(x0.none() && x1.none());
@@ -334,14 +334,14 @@ namespace Gecode { namespace Int { namespace Bool {
       return new (home) QuadOrTrue<BV>(home,share,*this);
   }
 
-  template <class BV>
+  template<class BV>
   forceinline ExecStatus
-  QuadOrTrue<BV>::post(Space& home, BV b0, BV b1, BV b2, BV b3) {
+  QuadOrTrue<BV>::post(Home home, BV b0, BV b1, BV b2, BV b3) {
     (void) new (home) QuadOrTrue<BV>(home,b0,b1,b2,b3);
     return ES_OK;
   }
 
-  template <class BV>
+  template<class BV>
   ExecStatus
   QuadOrTrue<BV>::propagate(Space& home, const ModEventDelta&) {
 #define GECODE_INT_STATUS(S0,S1,S2,S3)                        \
@@ -468,23 +468,23 @@ namespace Gecode { namespace Int { namespace Bool {
    *
    */
 
-  template <class BVA, class BVB, class BVC>
+  template<class BVA, class BVB, class BVC>
   forceinline
-  Or<BVA,BVB,BVC>::Or(Space& home, BVA b0, BVB b1, BVC b2)
+  Or<BVA,BVB,BVC>::Or(Home home, BVA b0, BVB b1, BVC b2)
     : BoolTernary<BVA,BVB,BVC>(home,b0,b1,b2) {}
 
-  template <class BVA, class BVB, class BVC>
+  template<class BVA, class BVB, class BVC>
   forceinline
   Or<BVA,BVB,BVC>::Or(Space& home, bool share, Or<BVA,BVB,BVC>& p)
     : BoolTernary<BVA,BVB,BVC>(home,share,p) {}
 
-  template <class BVA, class BVB, class BVC>
+  template<class BVA, class BVB, class BVC>
   forceinline
   Or<BVA,BVB,BVC>::Or(Space& home, bool share, Propagator& p,
                         BVA b0, BVB b1, BVC b2)
     : BoolTernary<BVA,BVB,BVC>(home,share,p,b0,b1,b2) {}
 
-  template <class BVA, class BVB, class BVC>
+  template<class BVA, class BVB, class BVC>
   Actor*
   Or<BVA,BVB,BVC>::copy(Space& home, bool share) {
     if (x2.one()) {
@@ -501,9 +501,9 @@ namespace Gecode { namespace Int { namespace Bool {
     }
   }
 
-  template <class BVA, class BVB, class BVC>
+  template<class BVA, class BVB, class BVC>
   inline ExecStatus
-  Or<BVA,BVB,BVC>::post(Space& home, BVA b0, BVB b1, BVC b2) {
+  Or<BVA,BVB,BVC>::post(Home home, BVA b0, BVB b1, BVC b2) {
     if (b2.zero()) {
       GECODE_ME_CHECK(b0.zero(home));
       GECODE_ME_CHECK(b1.zero(home));
@@ -533,7 +533,7 @@ namespace Gecode { namespace Int { namespace Bool {
     return ES_OK;
   }
 
-  template <class BVA, class BVB, class BVC>
+  template<class BVA, class BVB, class BVC>
   ExecStatus
   Or<BVA,BVB,BVC>::propagate(Space& home, const ModEventDelta&) {
 #define GECODE_INT_STATUS(S0,S1,S2) \
@@ -625,7 +625,7 @@ namespace Gecode { namespace Int { namespace Bool {
 
   template<class BV>
   forceinline
-  NaryOrTrue<BV>::NaryOrTrue(Space& home, ViewArray<BV>& b)
+  NaryOrTrue<BV>::NaryOrTrue(Home home, ViewArray<BV>& b)
     : BinaryPropagator<BV,PC_BOOL_VAL>(home,
                                       b[b.size()-2],
                                       b[b.size()-1]), x(b) {
@@ -677,7 +677,7 @@ namespace Gecode { namespace Int { namespace Bool {
 
   template<class BV>
   inline ExecStatus
-  NaryOrTrue<BV>::post(Space& home, ViewArray<BV>& b) {
+  NaryOrTrue<BV>::post(Home home, ViewArray<BV>& b) {
     for (int i=b.size(); i--; )
       if (b[i].one())
         return ES_OK;
@@ -713,7 +713,8 @@ namespace Gecode { namespace Int { namespace Bool {
         } else {
           // Rewrite if there is just one view left
           if (i == 0) {
-            GECODE_REWRITE(*this,(BinOrTrue<BV,BV>::post(home,x1,x[0])));
+            GECODE_REWRITE(*this,
+                           (BinOrTrue<BV,BV>::post(home(*this),x1,x[0])));
           }
           // Move to x0 and subscribe
           x0=x[i]; x[i]=x[--n];
@@ -759,7 +760,7 @@ namespace Gecode { namespace Int { namespace Bool {
 
   template<class VX, class VY>
   forceinline
-  NaryOr<VX,VY>::NaryOr(Space& home, ViewArray<VX>& x, VY y)
+  NaryOr<VX,VY>::NaryOr(Home home, ViewArray<VX>& x, VY y)
     : MixNaryOnePropagator<VX,PC_BOOL_NONE,VY,PC_BOOL_VAL>(home,x,y),
       n_zero(0), c(home) {
     x.subscribe(home,*new (home) Advisor(home,*this,c));
@@ -792,7 +793,7 @@ namespace Gecode { namespace Int { namespace Bool {
 
   template<class VX, class VY>
   inline ExecStatus
-  NaryOr<VX,VY>::post(Space& home, ViewArray<VX>& x, VY y) {
+  NaryOr<VX,VY>::post(Home home, ViewArray<VX>& x, VY y) {
     assert(!x.shared(home));
     if (y.one())
       return NaryOrTrue<VX>::post(home,x);
@@ -840,20 +841,21 @@ namespace Gecode { namespace Int { namespace Bool {
   ExecStatus
   NaryOr<VX,VY>::propagate(Space& home, const ModEventDelta&) {
     if (y.one())
-      GECODE_REWRITE(*this,NaryOrTrue<VX>::post(home,x));
-    Advisors<Advisor> as(c);
-    x.cancel(home,as.advisor());
-    c.dispose(home);
+      GECODE_REWRITE(*this,NaryOrTrue<VX>::post(home(*this),x));
     if (y.zero()) {
+      // Note that this might trigger the advisor of this propagator!
       for (int i = x.size(); i--; )
         GECODE_ME_CHECK(x[i].zero(home));
     } else if (n_zero == x.size()) {
       // All views are zero
       GECODE_ME_CHECK(y.zero_none(home));
     } else {
+      Advisors<Advisor> as(c);
+      x.cancel(home,as.advisor());
       // There is exactly one view which is one
       GECODE_ME_CHECK(y.one_none(home));
     }
+    c.dispose(home);
     return ES_SUBSUMED(*this,sizeof(*this));
   }
 
