@@ -7,8 +7,8 @@
  *     Christian Schulte, 2003
  *
  *  Last modified:
- *     $Date: 2009-02-03 11:13:22 +0100 (Tue, 03 Feb 2009) $ by $Author: schulte $
- *     $Revision: 8129 $
+ *     $Date: 2009-10-14 12:19:49 +0200 (Wed, 14 Oct 2009) $ by $Author: schulte $
+ *     $Revision: 9909 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -37,9 +37,9 @@
 
 namespace Gecode { namespace Int { namespace Distinct {
 
-  template <class View>
+  template<class View>
   forceinline
-  Bnd<View>::Bnd(Space& home, ViewArray<View>& x0)
+  Bnd<View>::Bnd(Home home, ViewArray<View>& x0)
     : Propagator(home), x(x0), y(home,x0) {
     // Both x and y initially contain the same variables
     //  - x is used for bounds propagation
@@ -49,7 +49,7 @@ namespace Gecode { namespace Int { namespace Distinct {
     y.subscribe(home,*this,PC_INT_BND);
   }
 
-  template <class View>
+  template<class View>
   forceinline size_t
   Bnd<View>::dispose(Space& home) {
     y.cancel(home,*this,PC_INT_BND);
@@ -57,7 +57,7 @@ namespace Gecode { namespace Int { namespace Distinct {
     return sizeof(*this);
   }
 
-  template <class View>
+  template<class View>
   forceinline
   Bnd<View>::Bnd(Space& home, bool share, Bnd<View>& p)
     : Propagator(home,share,p) {
@@ -65,13 +65,13 @@ namespace Gecode { namespace Int { namespace Distinct {
       y.update(home,share,p.y);
   }
 
-  template <class View>
+  template<class View>
   Actor*
   Bnd<View>::copy(Space& home, bool share) {
     return new (home) Bnd<View>(home,share,*this);
   }
 
-  template <class View>
+  template<class View>
   PropCost
   Bnd<View>::cost(const Space&, const ModEventDelta& med) const {
     if (View::me(med) == ME_INT_VAL)
@@ -88,7 +88,7 @@ namespace Gecode { namespace Int { namespace Distinct {
   };
 
   /// Sort-order by increasing maximum
-  template <class View>
+  template<class View>
   class MaxInc {
   protected:
     ViewArray<View> x;
@@ -101,7 +101,7 @@ namespace Gecode { namespace Int { namespace Distinct {
   };
 
   /// Sort-order by increasing minimum
-  template <class View>
+  template<class View>
   class MinInc {
   public:
     forceinline bool
@@ -163,7 +163,7 @@ namespace Gecode { namespace Int { namespace Distinct {
 #define GECODE_INT_MINSORTED(i) (i)
 #define GECODE_INT_MAXSORTED(i) (_maxsorted[i])
 
-  template <class View>
+  template<class View>
   ExecStatus
   prop_bnd(Space& home, ViewArray<View>& x) {
     const int n = x.size();
@@ -291,7 +291,7 @@ namespace Gecode { namespace Int { namespace Distinct {
 #undef GECODE_INT_MINSORTED
 #undef GECODE_INT_MAXSORTED
 
-  template <class View>
+  template<class View>
   ExecStatus
   Bnd<View>::propagate(Space& home, const ModEventDelta& med) {
     assert(x.size() > 1);
@@ -306,7 +306,7 @@ namespace Gecode { namespace Int { namespace Distinct {
     }
 
     if (y.size() == 2)
-      GECODE_REWRITE(*this,Rel::Nq<View>::post(home,y[0],y[1]));
+      GECODE_REWRITE(*this,Rel::Nq<View>::post(home(*this),y[0],y[1]));
 
     ExecStatus es = prop_bnd<View>(home,x);
 
@@ -339,14 +339,14 @@ namespace Gecode { namespace Int { namespace Distinct {
       return ES_SUBSUMED(*this,home);
 
     if (x.size() == 2)
-      GECODE_REWRITE(*this,Rel::Nq<View>::post(home,x[0],x[1]));
+      GECODE_REWRITE(*this,Rel::Nq<View>::post(home(*this),x[0],x[1]));
 
     return es;
   }
 
-  template <class View>
+  template<class View>
   ExecStatus
-  Bnd<View>::post(Space& home, ViewArray<View>& x){
+  Bnd<View>::post(Home home, ViewArray<View>& x){
     if (x.size() == 2)
       return Rel::Nq<View>::post(home,x[0],x[1]);
     if (x.size() > 2)
