@@ -7,8 +7,8 @@
  *     Christian Schulte, 2002
  *
  *  Last modified:
- *     $Date: 2009-01-20 23:44:27 +0100 (Tue, 20 Jan 2009) $ by $Author: schulte $
- *     $Revision: 8082 $
+ *     $Date: 2009-11-04 17:06:58 +0100 (Wed, 04 Nov 2009) $ by $Author: tack $
+ *     $Revision: 10046 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -132,9 +132,9 @@ namespace Gecode { namespace Int { namespace Linear {
    * \brief Posting n-ary propagators
    *
    */
-  template <class Val, class View>
+  template<class Val, class View>
   forceinline void
-  post_nary(Space& home,
+  post_nary(Home home,
             ViewArray<View>& x, ViewArray<View>& y, IntRelType r, Val c) {
     switch (r) {
     case IRT_EQ:
@@ -152,21 +152,21 @@ namespace Gecode { namespace Int { namespace Linear {
 
 
 /// Macro for posting binary special cases for linear constraints
-#define GECODE_INT_PL_BIN(CLASS)                                \
-  switch (n_p) {                                                \
-  case 2:                                                       \
-    GECODE_ES_FAIL(home,(CLASS<int,IntView,IntView>::post       \
-                         (home,t_p[0].x,t_p[1].x,c)));          \
-    break;                                                      \
-  case 1:                                                       \
-    GECODE_ES_FAIL(home,(CLASS<int,IntView,MinusView>::post     \
-                         (home,t_p[0].x,t_n[0].x,c)));          \
-    break;                                                      \
-  case 0:                                                       \
-    GECODE_ES_FAIL(home,(CLASS<int,MinusView,MinusView>::post   \
-                         (home,t_n[0].x,t_n[1].x,c)));          \
-    break;                                                      \
-  default: GECODE_NEVER;                                        \
+#define GECODE_INT_PL_BIN(CLASS)                                             \
+  switch (n_p) {                                                             \
+  case 2:                                                                    \
+    GECODE_ES_FAIL(home,(CLASS<int,IntView,IntView>::post                    \
+                         (home,t_p[0].x,t_p[1].x,c)));                       \
+    break;                                                                   \
+  case 1:                                                                    \
+    GECODE_ES_FAIL(home,(CLASS<int,IntView,MinusView>::post                  \
+                         (home,t_p[0].x,MinusView(t_n[0].x),c)));            \
+    break;                                                                   \
+  case 0:                                                                    \
+    GECODE_ES_FAIL(home,(CLASS<int,MinusView,MinusView>::post                \
+                         (home,MinusView(t_n[0].x),MinusView(t_n[1].x),c))); \
+    break;                                                                   \
+  default: GECODE_NEVER;                                                     \
   }
 
 /// Macro for posting ternary special cases for linear constraints
@@ -178,21 +178,24 @@ namespace Gecode { namespace Int { namespace Linear {
     break;                                                              \
   case 2:                                                               \
     GECODE_ES_FAIL(home,(CLASS<int,IntView,IntView,MinusView>::post     \
-                         (home,t_p[0].x,t_p[1].x,t_n[0].x,c)));         \
+                         (home,t_p[0].x,t_p[1].x,                       \
+                          MinusView(t_n[0].x),c)));                     \
     break;                                                              \
   case 1:                                                               \
     GECODE_ES_FAIL(home,(CLASS<int,IntView,MinusView,MinusView>::post   \
-                         (home,t_p[0].x,t_n[0].x,t_n[1].x,c)));         \
+                         (home,t_p[0].x,                                \
+                          MinusView(t_n[0].x),MinusView(t_n[1].x),c))); \
     break;                                                              \
   case 0:                                                               \
     GECODE_ES_FAIL(home,(CLASS<int,MinusView,MinusView,MinusView>::post \
-                         (home,t_n[0].x,t_n[1].x,t_n[2].x,c)));         \
+                         (home,MinusView(t_n[0].x),                     \
+                          MinusView(t_n[1].x),MinusView(t_n[2].x),c))); \
     break;                                                              \
   default: GECODE_NEVER;                                                \
   }
 
   void
-  post(Space& home, Term<IntView>* t, int n, IntRelType r, int c,
+  post(Home home, Term<IntView>* t, int n, IntRelType r, int c,
        IntConLevel icl) {
 
     Limits::check(c,"Int::linear");
@@ -304,9 +307,9 @@ namespace Gecode { namespace Int { namespace Linear {
    * \brief Posting reified n-ary propagators
    *
    */
-  template <class Val, class View>
+  template<class Val, class View>
   forceinline void
-  post_nary(Space& home,
+  post_nary(Home home,
             ViewArray<View>& x, ViewArray<View>& y,
             IntRelType r, Val c, BoolView b) {
     switch (r) {
@@ -328,7 +331,7 @@ namespace Gecode { namespace Int { namespace Linear {
   }
 
   void
-  post(Space& home,
+  post(Home home,
        Term<IntView>* t, int n, IntRelType r, int c, BoolView b,
        IntConLevel) {
 
@@ -406,7 +409,7 @@ namespace Gecode { namespace Int { namespace Linear {
             break;
           case 1:
             GECODE_ES_FAIL(home,(ReEqBin<int,IntView,MinusView,BoolView>::post
-                                 (home,t_p[0].x,t_n[0].x,c,b)));
+                                 (home,t_p[0].x,MinusView(t_n[0].x),c,b)));
             break;
           case 0:
             GECODE_ES_FAIL(home,(ReEqBin<int,IntView,IntView,BoolView>::post
@@ -427,12 +430,13 @@ namespace Gecode { namespace Int { namespace Linear {
             case 1:
               GECODE_ES_FAIL(home,
                              (ReEqBin<int,IntView,MinusView,NegBoolView>::post
-                              (home,t_p[0].x,t_n[0].x,c,b)));
+                              (home,t_p[0].x,MinusView(t_n[0].x),c,
+                               NegBoolView(b))));
               break;
             case 0:
               GECODE_ES_FAIL(home,
                              (ReEqBin<int,IntView,IntView,NegBoolView>::post
-                              (home,t_p[0].x,t_p[1].x,-c,b)));
+                              (home,t_p[0].x,t_p[1].x,-c,NegBoolView(b))));
               break;
             default: GECODE_NEVER;
             }
@@ -446,11 +450,12 @@ namespace Gecode { namespace Int { namespace Linear {
             break;
           case 1:
             GECODE_ES_FAIL(home,(ReLqBin<int,IntView,MinusView>::post
-                                 (home,t_p[0].x,t_n[0].x,c,b)));
+                                 (home,t_p[0].x,MinusView(t_n[0].x),c,b)));
             break;
           case 0:
             GECODE_ES_FAIL(home,(ReLqBin<int,MinusView,MinusView>::post
-                                 (home,t_n[0].x,t_n[1].x,c,b)));
+                                 (home,MinusView(t_n[0].x),
+                                  MinusView(t_n[1].x),c,b)));
             break;
           default: GECODE_NEVER;
           }
