@@ -7,8 +7,8 @@
  *     Christian Schulte, 2004
  *
  *  Last modified:
- *     $Date: 2009-02-03 11:13:22 +0100 (Tue, 03 Feb 2009) $ by $Author: schulte $
- *     $Revision: 8129 $
+ *     $Date: 2009-11-04 17:06:05 +0100 (Wed, 04 Nov 2009) $ by $Author: tack $
+ *     $Revision: 10045 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -42,14 +42,14 @@ namespace Gecode { namespace Int { namespace Rel {
    *
    */
 
-  template <class View0, class View1>
+  template<class View0, class View1>
   forceinline
-  EqBnd<View0,View1>::EqBnd(Space& home, View0 x0, View1 x1)
+  EqBnd<View0,View1>::EqBnd(Home home, View0 x0, View1 x1)
     : MixBinaryPropagator<View0,PC_INT_BND,View1,PC_INT_BND>(home,x0,x1) {}
 
-  template <class View0, class View1>
+  template<class View0, class View1>
   ExecStatus
-  EqBnd<View0,View1>::post(Space& home, View0 x0, View1 x1){
+  EqBnd<View0,View1>::post(Home home, View0 x0, View1 x1){
     if (x0.assigned()) {
       GECODE_ME_CHECK(x1.eq(home,x0.val()));
     } else if (x1.assigned()) {
@@ -64,25 +64,25 @@ namespace Gecode { namespace Int { namespace Rel {
     return ES_OK;
   }
 
-  template <class View0, class View1>
+  template<class View0, class View1>
   forceinline
   EqBnd<View0,View1>::EqBnd(Space& home, bool share, EqBnd<View0,View1>& p)
     : MixBinaryPropagator<View0,PC_INT_BND,View1,PC_INT_BND>(home,share,p) {}
 
-  template <class View0, class View1>
+  template<class View0, class View1>
   forceinline
   EqBnd<View0,View1>::EqBnd(Space& home, bool share, Propagator& p,
                             View0 x0, View1 x1)
     : MixBinaryPropagator<View0,PC_INT_BND,View1,PC_INT_BND>(home,share,p,
                                                              x0,x1) {}
 
-  template <class View0, class View1>
+  template<class View0, class View1>
   Actor*
   EqBnd<View0,View1>::copy(Space& home, bool share) {
     return new (home) EqBnd<View0,View1>(home,share,*this);
   }
 
-  template <class View0, class View1>
+  template<class View0, class View1>
   ExecStatus
   EqBnd<View0,View1>::propagate(Space& home, const ModEventDelta&) {
     if (x0.assigned()) {
@@ -110,14 +110,14 @@ namespace Gecode { namespace Int { namespace Rel {
    *
    */
 
-  template <class View0, class View1>
+  template<class View0, class View1>
   forceinline
-  EqDom<View0,View1>::EqDom(Space& home, View0 x0, View1 x1)
+  EqDom<View0,View1>::EqDom(Home home, View0 x0, View1 x1)
     : MixBinaryPropagator<View0,PC_INT_DOM,View1,PC_INT_DOM>(home,x0,x1) {}
 
-  template <class View0, class View1>
+  template<class View0, class View1>
   ExecStatus
-  EqDom<View0,View1>::post(Space& home, View0 x0, View1 x1){
+  EqDom<View0,View1>::post(Home home, View0 x0, View1 x1){
     if (x0.assigned()) {
       GECODE_ME_CHECK(x1.eq(home,x0.val()));
     } else if (x1.assigned()) {
@@ -133,25 +133,25 @@ namespace Gecode { namespace Int { namespace Rel {
   }
 
 
-  template <class View0, class View1>
+  template<class View0, class View1>
   forceinline
   EqDom<View0,View1>::EqDom(Space& home, bool share, EqDom<View0,View1>& p)
     : MixBinaryPropagator<View0,PC_INT_DOM,View1,PC_INT_DOM>(home,share,p) {}
 
-  template <class View0, class View1>
+  template<class View0, class View1>
   forceinline
   EqDom<View0,View1>::EqDom(Space& home, bool share, Propagator& p,
                             View0 x0, View1 x1)
     : MixBinaryPropagator<View0,PC_INT_DOM,View1,PC_INT_DOM>(home,share,p,
                                                              x0,x1) {}
 
-  template <class View0, class View1>
+  template<class View0, class View1>
   Actor*
   EqDom<View0,View1>::copy(Space& home, bool share) {
     return new (home) EqDom<View0,View1>(home,share,*this);
   }
 
-  template <class View0, class View1>
+  template<class View0, class View1>
   PropCost
   EqDom<View0,View1>::cost(const Space&, const ModEventDelta& med) const {
     if ((View0::me(med) == ME_INT_VAL) || (View1::me(med) == ME_INT_VAL))
@@ -162,7 +162,7 @@ namespace Gecode { namespace Int { namespace Rel {
       return PropCost::binary(PropCost::HI);
   }
 
-  template <class View0, class View1>
+  template<class View0, class View1>
   ExecStatus
   EqDom<View0,View1>::propagate(Space& home, const ModEventDelta& med) {
     if (x0.assigned()) {
@@ -189,9 +189,9 @@ namespace Gecode { namespace Int { namespace Rel {
       return ES_FIX_PARTIAL(*this,View0::med(ME_INT_DOM));
     }
     ViewRanges<View0> r0(x0);
-    GECODE_ME_CHECK(x1.inter_r(home,r0,false));
+    GECODE_ME_CHECK(x1.inter_r(home,r0,shared(x0,x1)));
     ViewRanges<View1> r1(x1);
-    GECODE_ME_CHECK(x0.narrow_r(home,r1,false));
+    GECODE_ME_CHECK(x0.narrow_r(home,r1,shared(x0,x1)));
     if (x0.assigned())
       return ES_SUBSUMED(*this,sizeof(*this));
     return ES_FIX;
@@ -204,14 +204,14 @@ namespace Gecode { namespace Int { namespace Rel {
    *
    */
 
-  template <class View>
+  template<class View>
   forceinline
-  NaryEqDom<View>::NaryEqDom(Space& home, ViewArray<View>& x)
+  NaryEqDom<View>::NaryEqDom(Home home, ViewArray<View>& x)
     : NaryPropagator<View,PC_INT_DOM>(home,x) {}
 
-  template <class View>
+  template<class View>
   ExecStatus
-  NaryEqDom<View>::post(Space& home, ViewArray<View>& x) {
+  NaryEqDom<View>::post(Home home, ViewArray<View>& x) {
     x.unique(home);
     if (x.size() == 2) {
       return EqDom<View,View>::post(home,x[0],x[1]);
@@ -231,18 +231,18 @@ namespace Gecode { namespace Int { namespace Rel {
     return ES_OK;
   }
 
-  template <class View>
+  template<class View>
   forceinline
   NaryEqDom<View>::NaryEqDom(Space& home, bool share, NaryEqDom<View>& p)
     : NaryPropagator<View,PC_INT_DOM>(home,share,p) {}
 
-  template <class View>
+  template<class View>
   Actor*
   NaryEqDom<View>::copy(Space& home, bool share) {
     return new (home) NaryEqDom<View>(home,share,*this);
   }
 
-  template <class View>
+  template<class View>
   PropCost
   NaryEqDom<View>::cost(const Space&, const ModEventDelta& med) const {
     if (View::me(med) == ME_INT_VAL)
@@ -252,7 +252,7 @@ namespace Gecode { namespace Int { namespace Rel {
                               PropCost::LO : PropCost::HI, x.size());
   }
 
-  template <class View>
+  template<class View>
   ExecStatus
   NaryEqDom<View>::propagate(Space& home, const ModEventDelta& med) {
     assert(x.size() > 2);
@@ -338,14 +338,14 @@ namespace Gecode { namespace Int { namespace Rel {
    *
    */
 
-  template <class View>
+  template<class View>
   forceinline
-  NaryEqBnd<View>::NaryEqBnd(Space& home, ViewArray<View>& x)
+  NaryEqBnd<View>::NaryEqBnd(Home home, ViewArray<View>& x)
     : NaryPropagator<View,PC_INT_BND>(home,x) {}
 
-  template <class View>
+  template<class View>
   ExecStatus
-  NaryEqBnd<View>::post(Space& home, ViewArray<View>& x) {
+  NaryEqBnd<View>::post(Home home, ViewArray<View>& x) {
     if (x.size() == 2) {
       return EqBnd<View,View>::post(home,x[0],x[1]);
     } else if (x.size() > 2) {
@@ -364,18 +364,18 @@ namespace Gecode { namespace Int { namespace Rel {
     return ES_OK;
   }
 
-  template <class View>
+  template<class View>
   forceinline
   NaryEqBnd<View>::NaryEqBnd(Space& home, bool share, NaryEqBnd<View>& p)
     : NaryPropagator<View,PC_INT_BND>(home,share,p) {}
 
-  template <class View>
+  template<class View>
   Actor*
   NaryEqBnd<View>::copy(Space& home, bool share) {
     return new (home) NaryEqBnd<View>(home,share,*this);
   }
 
-  template <class View>
+  template<class View>
   PropCost
   NaryEqBnd<View>::cost(const Space&, const ModEventDelta& med) const {
     if (View::me(med) == ME_INT_VAL)
@@ -384,7 +384,7 @@ namespace Gecode { namespace Int { namespace Rel {
       return PropCost::linear(PropCost::LO, x.size());
   }
 
-  template <class View>
+  template<class View>
   ExecStatus
   NaryEqBnd<View>::propagate(Space& home, const ModEventDelta& med) {
     assert(x.size() > 2);
@@ -430,14 +430,14 @@ namespace Gecode { namespace Int { namespace Rel {
    *
    */
 
-  template <class View, class CtrlView>
+  template<class View, class CtrlView>
   forceinline
-  ReEqDom<View,CtrlView>::ReEqDom(Space& home, View x0, View x1, CtrlView b)
+  ReEqDom<View,CtrlView>::ReEqDom(Home home, View x0, View x1, CtrlView b)
     : ReBinaryPropagator<View,PC_INT_DOM,CtrlView>(home,x0,x1,b) {}
 
-  template <class View, class CtrlView>
+  template<class View, class CtrlView>
   ExecStatus
-  ReEqDom<View,CtrlView>::post(Space& home, View x0, View x1, CtrlView b) {
+  ReEqDom<View,CtrlView>::post(Home home, View x0, View x1, CtrlView b) {
     if (b.one())
       return EqDom<View,View>::post(home,x0,x1);
     if (b.zero())
@@ -451,24 +451,24 @@ namespace Gecode { namespace Int { namespace Rel {
   }
 
 
-  template <class View, class CtrlView>
+  template<class View, class CtrlView>
   forceinline
   ReEqDom<View,CtrlView>::ReEqDom(Space& home, bool share, ReEqDom& p)
     : ReBinaryPropagator<View,PC_INT_DOM,CtrlView>(home,share,p) {}
 
-  template <class View, class CtrlView>
+  template<class View, class CtrlView>
   Actor*
   ReEqDom<View,CtrlView>::copy(Space& home, bool share) {
     return new (home) ReEqDom<View,CtrlView>(home,share,*this);
   }
 
-  template <class View, class CtrlView>
+  template<class View, class CtrlView>
   ExecStatus
   ReEqDom<View,CtrlView>::propagate(Space& home, const ModEventDelta&) {
     if (b.one())
-      GECODE_REWRITE(*this,(EqDom<View,View>::post(home,x0,x1)));
+      GECODE_REWRITE(*this,(EqDom<View,View>::post(home(*this),x0,x1)));
     if (b.zero())
-      GECODE_REWRITE(*this,Nq<View>::post(home,x0,x1));
+      GECODE_REWRITE(*this,Nq<View>::post(home(*this),x0,x1));
     switch (rtest_eq_dom(x0,x1)) {
     case RT_TRUE:
       GECODE_ME_CHECK(b.one_none(home)); return ES_SUBSUMED(*this,home);
@@ -488,14 +488,14 @@ namespace Gecode { namespace Int { namespace Rel {
    *
    */
 
-  template <class View, class CtrlView>
+  template<class View, class CtrlView>
   forceinline
-  ReEqBnd<View,CtrlView>::ReEqBnd(Space& home, View x0, View x1, CtrlView b)
+  ReEqBnd<View,CtrlView>::ReEqBnd(Home home, View x0, View x1, CtrlView b)
     : ReBinaryPropagator<View,PC_INT_BND,CtrlView>(home,x0,x1,b) {}
 
-  template <class View, class CtrlView>
+  template<class View, class CtrlView>
   ExecStatus
-  ReEqBnd<View,CtrlView>::post(Space& home, View x0, View x1, CtrlView b){
+  ReEqBnd<View,CtrlView>::post(Home home, View x0, View x1, CtrlView b){
     if (b.one())
       return EqBnd<View,View>::post(home,x0,x1);
     if (b.zero())
@@ -509,24 +509,24 @@ namespace Gecode { namespace Int { namespace Rel {
   }
 
 
-  template <class View, class CtrlView>
+  template<class View, class CtrlView>
   forceinline
   ReEqBnd<View,CtrlView>::ReEqBnd(Space& home, bool share, ReEqBnd& p)
     : ReBinaryPropagator<View,PC_INT_BND,CtrlView>(home,share,p) {}
 
-  template <class View, class CtrlView>
+  template<class View, class CtrlView>
   Actor*
   ReEqBnd<View,CtrlView>::copy(Space& home, bool share) {
     return new (home) ReEqBnd<View,CtrlView>(home,share,*this);
   }
 
-  template <class View, class CtrlView>
+  template<class View, class CtrlView>
   ExecStatus
   ReEqBnd<View,CtrlView>::propagate(Space& home, const ModEventDelta&) {
     if (b.one())
-      GECODE_REWRITE(*this,(EqBnd<View,View>::post(home,x0,x1)));
+      GECODE_REWRITE(*this,(EqBnd<View,View>::post(home(*this),x0,x1)));
     if (b.zero())
-      GECODE_REWRITE(*this,Nq<View>::post(home,x0,x1));
+      GECODE_REWRITE(*this,Nq<View>::post(home(*this),x0,x1));
     switch (rtest_eq_bnd(x0,x1)) {
     case RT_TRUE:
       GECODE_ME_CHECK(b.one_none(home));  return ES_SUBSUMED(*this,home);
@@ -547,15 +547,15 @@ namespace Gecode { namespace Int { namespace Rel {
    *
    */
 
-  template <class View, class CtrlView>
+  template<class View, class CtrlView>
   forceinline
   ReEqDomInt<View,CtrlView>::ReEqDomInt
-  (Space& home, View x, int c0, CtrlView b)
+  (Home home, View x, int c0, CtrlView b)
     : ReUnaryPropagator<View,PC_INT_DOM,CtrlView>(home,x,b), c(c0) {}
 
-  template <class View, class CtrlView>
+  template<class View, class CtrlView>
   ExecStatus
-  ReEqDomInt<View,CtrlView>::post(Space& home, View x, int c, CtrlView b) {
+  ReEqDomInt<View,CtrlView>::post(Home home, View x, int c, CtrlView b) {
     if (b.one()) {
       GECODE_ME_CHECK(x.eq(home,c));
     } else if (b.zero()) {
@@ -574,18 +574,18 @@ namespace Gecode { namespace Int { namespace Rel {
   }
 
 
-  template <class View, class CtrlView>
+  template<class View, class CtrlView>
   forceinline
   ReEqDomInt<View,CtrlView>::ReEqDomInt(Space& home, bool share, ReEqDomInt& p)
     : ReUnaryPropagator<View,PC_INT_DOM,CtrlView>(home,share,p), c(p.c) {}
 
-  template <class View, class CtrlView>
+  template<class View, class CtrlView>
   Actor*
   ReEqDomInt<View,CtrlView>::copy(Space& home, bool share) {
     return new (home) ReEqDomInt<View,CtrlView>(home,share,*this);
   }
 
-  template <class View, class CtrlView>
+  template<class View, class CtrlView>
   ExecStatus
   ReEqDomInt<View,CtrlView>::propagate(Space& home, const ModEventDelta&) {
     if (b.one()) {
@@ -624,15 +624,15 @@ namespace Gecode { namespace Int { namespace Rel {
    *
    */
 
-  template <class View, class CtrlView>
+  template<class View, class CtrlView>
   forceinline
   ReEqBndInt<View,CtrlView>::ReEqBndInt
-  (Space& home, View x, int c0, CtrlView b)
+  (Home home, View x, int c0, CtrlView b)
     : ReUnaryPropagator<View,PC_INT_BND,CtrlView>(home,x,b), c(c0) {}
 
-  template <class View, class CtrlView>
+  template<class View, class CtrlView>
   ExecStatus
-  ReEqBndInt<View,CtrlView>::post(Space& home, View x, int c, CtrlView b) {
+  ReEqBndInt<View,CtrlView>::post(Home home, View x, int c, CtrlView b) {
     if (b.one()) {
       GECODE_ME_CHECK(x.eq(home,c));
     } else if (b.zero()) {
@@ -651,18 +651,18 @@ namespace Gecode { namespace Int { namespace Rel {
   }
 
 
-  template <class View, class CtrlView>
+  template<class View, class CtrlView>
   forceinline
   ReEqBndInt<View,CtrlView>::ReEqBndInt(Space& home, bool share, ReEqBndInt& p)
     : ReUnaryPropagator<View,PC_INT_BND,CtrlView>(home,share,p), c(p.c) {}
 
-  template <class View, class CtrlView>
+  template<class View, class CtrlView>
   Actor*
   ReEqBndInt<View,CtrlView>::copy(Space& home, bool share) {
     return new (home) ReEqBndInt<View,CtrlView>(home,share,*this);
   }
 
-  template <class View, class CtrlView>
+  template<class View, class CtrlView>
   ExecStatus
   ReEqBndInt<View,CtrlView>::propagate(Space& home, const ModEventDelta&) {
     if (b.one()) {
