@@ -7,8 +7,8 @@
  *     Patrick Pekczynski, 2004
  *
  *  Last modified:
- *     $Date: 2009-02-05 12:16:51 +0100 (Thu, 05 Feb 2009) $ by $Author: schulte $
- *     $Revision: 8157 $
+ *     $Date: 2009-10-14 12:19:49 +0200 (Wed, 14 Oct 2009) $ by $Author: schulte $
+ *     $Revision: 9909 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -360,7 +360,7 @@ namespace Gecode { namespace Int { namespace Sorted {
 
   template<class View, bool Perm>
   Sorted<View,Perm>::
-  Sorted(Space& home,
+  Sorted(Home home,
          ViewArray<View>& x0, ViewArray<View>& y0, ViewArray<View>& z0) :
     Propagator(home), x(x0), y(y0), z(z0), w(home,y0), reachable(-1) {
     x.subscribe(home, *this, PC_INT_BND);
@@ -455,7 +455,7 @@ namespace Gecode { namespace Int { namespace Sorted {
         if (Perm) {
           GECODE_ME_CHECK(z[0].eq(home, w.size() - 1));
         }
-        GECODE_REWRITE(*this,(Rel::EqBnd<View,View>::post(home, x[0], y[0])));
+        GECODE_REWRITE(*this,(Rel::EqBnd<View,View>::post(home(*this), x[0], y[0])));
       }
 
       // check whether shifting the permutation variables
@@ -511,7 +511,7 @@ namespace Gecode { namespace Int { namespace Sorted {
       if (n < 2) {
         if (x[0].max() < y[0].min() || y[0].max() < x[0].min())
           return ES_FAILED;
-        GECODE_REWRITE(*this,(Rel::EqBnd<View,View>::post(home, x[0], y[0])));
+        GECODE_REWRITE(*this,(Rel::EqBnd<View,View>::post(home(*this), x[0], y[0])));
       }
 
       GECODE_ES_CHECK((bounds_propagation<View,Perm>
@@ -631,7 +631,7 @@ namespace Gecode { namespace Int { namespace Sorted {
   template<class View, bool Perm>
   ExecStatus
   Sorted<View,Perm>::
-  post(Space& home,
+  post(Home home,
        ViewArray<View>& x0, ViewArray<View>& y0, ViewArray<View>& z0) {
     int n = x0.size();
     if (n < 2) {
