@@ -9,8 +9,8 @@
  *     Christian Schulte, 2004
  *
  *  Last modified:
- *     $Date: 2009-03-25 21:23:05 +0100 (Wed, 25 Mar 2009) $ by $Author: schulte $
- *     $Revision: 8565 $
+ *     $Date: 2009-10-12 17:36:53 +0200 (Mon, 12 Oct 2009) $ by $Author: schulte $
+ *     $Revision: 9878 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -156,7 +156,7 @@ namespace Gecode {
   }
 
   BoolVar
-  BoolExpr::NNF::post(Space& home, IntConLevel icl) const {
+  BoolExpr::NNF::post(Home home, IntConLevel icl) const {
     if ((t == NT_VAR) && !u.a.neg)
       return u.a.x->x;
     BoolVar b(home,0,1);
@@ -214,7 +214,7 @@ namespace Gecode {
   }
 
   void
-  BoolExpr::NNF::post(Space& home, NodeType t,
+  BoolExpr::NNF::post(Home home, NodeType t,
                       BoolVarArgs& bp, BoolVarArgs& bn,
                       int& ip, int& in,
                       IntConLevel icl) const {
@@ -252,7 +252,7 @@ namespace Gecode {
   }
 
   void
-  BoolExpr::NNF::post(Space& home, bool b, IntConLevel icl) const {
+  BoolExpr::NNF::post(Home home, bool b, IntConLevel icl) const {
     if (b) {
       switch (t) {
       case NT_VAR:
