@@ -7,8 +7,8 @@
  *     Guido Tack, 2004
  *
  *  Last modified:
- *     $Date: 2009-01-20 23:44:27 +0100 (Tue, 20 Jan 2009) $ by $Author: schulte $
- *     $Revision: 8082 $
+ *     $Date: 2009-10-12 17:36:53 +0200 (Mon, 12 Oct 2009) $ by $Author: schulte $
+ *     $Revision: 9878 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -41,24 +41,24 @@ namespace Gecode {
    * Operations for nodes
    *
    */
-  template <class Var>
+  template<class Var>
   forceinline
   LinExpr<Var>::Node::Node(void) : use(1) {
   }
 
-  template <class Var>
+  template<class Var>
   forceinline void*
   LinExpr<Var>::Node::operator new(size_t size) {
     return heap.ralloc(size);
   }
 
-  template <class Var>
+  template<class Var>
   forceinline void
   LinExpr<Var>::Node::operator delete(void* p, size_t) {
     heap.rfree(p);
   }
 
-  template <class Var>
+  template<class Var>
   bool
   LinExpr<Var>::Node::decrement(void) {
     if (--use == 0) {
@@ -71,7 +71,7 @@ namespace Gecode {
     return false;
   }
 
-  template <class Var>
+  template<class Var>
   int
   LinExpr<Var>::Node::fill(Int::Linear::Term<View> t[],
                            int i, int m, int c_i, int& c_o) const {
@@ -115,7 +115,7 @@ namespace Gecode {
    *
    */
 
-  template <class Var>
+  template<class Var>
   inline
   LinExpr<Var>::LinExpr(void) :
     n(new Node) {
@@ -125,7 +125,7 @@ namespace Gecode {
     n->a = 0;
   }
 
-  template <class Var>
+  template<class Var>
   inline
   LinExpr<Var>::LinExpr(const Var& x, int a) :
     n(new Node) {
@@ -136,7 +136,7 @@ namespace Gecode {
     n->x = x;
   }
 
-  template <class Var>
+  template<class Var>
   inline
   LinExpr<Var>::LinExpr(const LinExpr& e0, NodeType t, const LinExpr& e1) :
     n(new Node) {
@@ -146,7 +146,7 @@ namespace Gecode {
     n->r = e1.n; n->r->use++;
   }
 
-  template <class Var>
+  template<class Var>
   inline
   LinExpr<Var>::LinExpr(const LinExpr& e, NodeType t, int c) :
     n(new Node) {
@@ -157,7 +157,7 @@ namespace Gecode {
     n->c = c;
   }
 
-  template <class Var>
+  template<class Var>
   inline
   LinExpr<Var>::LinExpr(int a, const LinExpr& e) :
     n(new Node) {
@@ -168,14 +168,14 @@ namespace Gecode {
     n->a = a;
   }
 
-  template <class Var>
+  template<class Var>
   inline
   LinExpr<Var>::LinExpr(const LinExpr<Var>& e)
     : n(e.n) {
     n->use++;
   }
 
-  template <class Var>
+  template<class Var>
   inline const LinExpr<Var>&
   LinExpr<Var>::operator =(const LinExpr<Var>& e) {
     if (this != &e) {
@@ -186,16 +186,16 @@ namespace Gecode {
     return *this;
   }
 
-  template <class Var>
+  template<class Var>
   forceinline
   LinExpr<Var>::~LinExpr(void) {
     if (n->decrement())
       delete n;
   }
 
-  template <class Var>
+  template<class Var>
   inline void
-  LinExpr<Var>::post(Space& home, IntRelType irt, IntConLevel icl) const {
+  LinExpr<Var>::post(Home home, IntRelType irt, IntConLevel icl) const {
     Region r(home);
     Int::Linear::Term<typename VarViewTraits<Var>::View>* ts =
       r.alloc<Int::Linear::Term<typename VarViewTraits<Var>::View> >(n->n);
@@ -204,9 +204,9 @@ namespace Gecode {
     Int::Linear::post(home, ts, i, irt, -c_o, icl);
   }
 
-  template <class Var>
+  template<class Var>
   inline void
-  LinExpr<Var>::post(Space& home, IntRelType irt, const BoolVar& b,
+  LinExpr<Var>::post(Home home, IntRelType irt, const BoolVar& b,
                      IntConLevel icl) const {
     Region r(home);
     Int::Linear::Term<typename VarViewTraits<Var>::View>* ts =
@@ -216,9 +216,9 @@ namespace Gecode {
     Int::Linear::post(home, ts, i, irt, -c_o, b, icl);
   }
 
-  template <>
+  template<>
   inline IntVar
-  LinExpr<IntVar>::post(Space& home, IntConLevel icl) const {
+  LinExpr<IntVar>::post(Home home, IntConLevel icl) const {
     Region r(home);
     Int::Linear::Term<Int::IntView>* ts =
       r.alloc<Int::Linear::Term<Int::IntView> >(n->n+1);
@@ -232,9 +232,9 @@ namespace Gecode {
     return x;
   }
 
-  template <>
+  template<>
   inline IntVar
-  LinExpr<BoolVar>::post(Space& home, IntConLevel icl) const {
+  LinExpr<BoolVar>::post(Home home, IntConLevel icl) const {
     Region r(home);
     Int::Linear::Term<Int::BoolView>* ts =
       r.alloc<Int::Linear::Term<Int::BoolView> >(n->n);
@@ -432,19 +432,19 @@ namespace Gecode {
 
 
   forceinline IntVar
-  post(Space&, const IntVar& x, IntConLevel) {
+  post(Home, const IntVar& x, IntConLevel) {
     return x;
   }
 
   inline IntVar
-  post(Space& home, int n, IntConLevel) {
+  post(Home home, int n, IntConLevel) {
     IntVar x(home, n, n);
     return x;
   }
 
-  template <class Var>
+  template<class Var>
   inline IntVar
-  post(Space& home, const LinExpr<Var>& e, IntConLevel icl) {
+  post(Home home, const LinExpr<Var>& e, IntConLevel icl) {
     if (!home.failed())
       return e.post(home,icl);
     IntVar x(home,Int::Limits::min,Int::Limits::max);
