@@ -7,8 +7,8 @@
  *     Christian Schulte, 2004
  *
  *  Last modified:
- *     $Date: 2009-01-20 23:44:27 +0100 (Tue, 20 Jan 2009) $ by $Author: schulte $
- *     $Revision: 8082 $
+ *     $Date: 2009-11-03 17:23:42 +0100 (Tue, 03 Nov 2009) $ by $Author: schulte $
+ *     $Revision: 10032 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -71,16 +71,14 @@ namespace Gecode {
     ExpType type;
     /// Symbol or subexpressions
     union {
-      /// Symbole
+      /// Symbol
       int  symbol;
       /// Subexpressions
       Exp* kids[2];
     } data;
 
-    void followpos(MiniModel::PosSetAllocator&,
-                   MiniModel::NodeInfo&,
-                   MiniModel::PosInfo*,
-                   int&);
+    MiniModel::PosSet*
+    followpos(MiniModel::PosSetAllocator&,MiniModel::PosInfo*);
     void inc(void);
     void dec(void);
     unsigned int n_pos(void) const;
@@ -445,18 +443,23 @@ namespace Gecode {
     }
 
 
-    /**
-     * \brief Node information computed during traversal of the expressions
-     *
-     */
+    /// Node information computed during traversal of the expressions
     class NodeInfo {
     public:
       bool    nullable;
       PosSet* firstpos;
       PosSet* lastpos;
+      NodeInfo(bool n=false, PosSet* fp=NULL, PosSet* lp=NULL);
     };
 
-
+    /// Expression information
+    class ExpInfo {
+    public:
+      REG::Exp* exp;
+      bool open;
+      ExpInfo(REG::Exp* e=NULL);
+    };
+    
     /**
      * \brief Information on positions collected during traversal
      *
@@ -467,70 +470,103 @@ namespace Gecode {
       PosSet* followpos;
     };
 
+    forceinline
+    NodeInfo::NodeInfo(bool n, PosSet* fp, PosSet* lp)
+      : nullable(n), firstpos(fp), lastpos(lp) {}
+
+    forceinline
+    ExpInfo::ExpInfo(REG::Exp* e)
+      : exp(e), open(true) {}
+
   }
 
-  void
+  forceinline MiniModel::PosSet*
   REG::Exp::followpos(MiniModel::PosSetAllocator& psm,
-                      MiniModel::NodeInfo& ni,
-                      MiniModel::PosInfo* pi, int& p) {
+                      MiniModel::PosInfo* pi) {
+    int p=0;
+
     using MiniModel::PosSet;
     using MiniModel::NodeInfo;
-    if (this == NULL) {
-      ni.nullable = true;
-      ni.firstpos = NULL;
-      ni.lastpos  = NULL;
-      return;
-    }
-    switch (type) {
-    case ET_SYMBOL:
-      {
-        pi[p].symbol = data.symbol;
-        PosSet* ps = new (psm) PosSet(p);
-        p++;
-        ni.nullable = false;
-        ni.firstpos = ps;
-        ni.lastpos  = ps;
+    using MiniModel::ExpInfo;
+
+    Support::DynamicStack<ExpInfo,Heap> todo(heap);
+    Support::DynamicStack<NodeInfo,Heap> done(heap);
+
+    // Start with first expression to be processed
+    todo.push(ExpInfo(this));
+
+    do {
+      if (todo.top().exp == NULL) {
+        todo.pop();
+        done.push(NodeInfo(true,NULL,NULL));
+      } else {
+        switch (todo.top().exp->type) {
+        case ET_SYMBOL:
+          {
+            pi[p].symbol = todo.pop().exp->data.symbol;
+            PosSet* ps = new (psm) PosSet(p++);
+            done.push(NodeInfo(false,ps,ps));
+          }
+          break;
+        case ET_STAR:
+          if (todo.top().open) {
+            // Evaluate subexpression recursively
+            todo.top().open = false;
+            todo.push(todo.top().exp->data.kids[0]);
+          } else {
+            todo.pop();
+            NodeInfo ni = done.pop();
+            for (PosSet* ps = ni.lastpos; ps != NULL; ps = ps->next)
+              pi[ps->pos].followpos =
+                PosSet::cup(psm,pi[ps->pos].followpos,ni.firstpos);
+            done.push(NodeInfo(true,ni.firstpos,ni.lastpos));
+          }
+          break;
+        case ET_CONC:
+          if (todo.top().open) {
+            // Evaluate subexpressions recursively
+            todo.top().open = false;
+            REG::Exp* e = todo.top().exp;
+            todo.push(e->data.kids[1]);
+            todo.push(e->data.kids[0]);
+          } else {
+            todo.pop();
+            NodeInfo ni1 = done.pop();
+            NodeInfo ni0 = done.pop();
+            for (PosSet* ps = ni0.lastpos; ps != NULL; ps = ps->next)
+              pi[ps->pos].followpos =
+                PosSet::cup(psm,pi[ps->pos].followpos,ni1.firstpos);
+            done.push(NodeInfo(ni0.nullable & ni1.nullable,
+                               ni0.nullable ? 
+                               PosSet::cup(psm,ni0.firstpos,ni1.firstpos) : ni0.firstpos,
+                               ni1.nullable ? 
+                               PosSet::cup(psm,ni0.lastpos,ni1.lastpos) : ni1.lastpos));
+          }
+          break;
+        case ET_OR:
+          if (todo.top().open) {
+            // Evaluate subexpressions recursively
+            todo.top().open = false;
+            REG::Exp* e = todo.top().exp;
+            todo.push(e->data.kids[1]);
+            todo.push(e->data.kids[0]);
+          } else {
+            todo.pop();
+            NodeInfo ni1 = done.pop();
+            NodeInfo ni0 = done.pop();
+            done.push(NodeInfo(ni0.nullable | ni1.nullable,
+                               PosSet::cup(psm,ni0.firstpos,ni1.firstpos),
+                               PosSet::cup(psm,ni0.lastpos,ni1.lastpos)));
+          }
+          break;
+        default: GECODE_NEVER;
+        }
       }
-      break;
-    case ET_STAR:
-      {
-        data.kids[0]->followpos(psm, ni, pi, p);
-        ni.nullable = true;
-        for (PosSet* ps = ni.lastpos; ps != NULL; ps = ps->next)
-          pi[ps->pos].followpos =
-            PosSet::cup(psm,pi[ps->pos].followpos, ni.firstpos);
-      }
-      break;
-    case ET_CONC:
-      {
-        NodeInfo ni0; data.kids[0]->followpos(psm, ni0, pi, p);
-        data.kids[1]->followpos(psm, ni, pi, p);
-        for (PosSet* ps = ni0.lastpos; ps != NULL; ps = ps->next)
-          pi[ps->pos].followpos =
-            PosSet::cup(psm,pi[ps->pos].followpos,ni.firstpos);
-        ni.firstpos =
-          ni0.nullable ? PosSet::cup(psm,ni0.firstpos,ni.firstpos)
-          : ni0.firstpos;
-        ni.lastpos =
-          ni.nullable ? PosSet::cup(psm,ni0.lastpos,ni.lastpos)
-          : ni.lastpos;
-        ni.nullable &= ni0.nullable;
-      }
-      break;
-    case ET_OR:
-      {
-        NodeInfo ni0; data.kids[0]->followpos(psm, ni0, pi, p);
-        data.kids[1]->followpos(psm, ni, pi, p);
-        ni.nullable |= ni0.nullable;
-        ni.firstpos = PosSet::cup(psm,ni0.firstpos,ni.firstpos);
-        ni.lastpos  = PosSet::cup(psm,ni0.lastpos,ni.lastpos);
-      }
-      break;
-    default: GECODE_NEVER;
-    }
+    } while (!todo.empty());
+    return done.top().firstpos;
   }
 
-
+    
   namespace MiniModel {
 
     class StateNode;
@@ -733,10 +769,7 @@ namespace Gecode {
     for (int i=n_pos; i--; )
       pi[i].followpos = NULL;
 
-    NodeInfo ni_root;
-    int n_p = 0;
-    r.e->followpos(psm,ni_root,&pi[0],n_p);
-    assert(n_p == n_pos);
+    PosSet* firstpos = r.e->followpos(psm,&pi[0]);
 
     // Compute symbols
     int* symbols = heap.alloc<int>(n_pos);
@@ -751,7 +784,7 @@ namespace Gecode {
 
     // Compute states and transitions
     TransitionBag tb;
-    StatePool sp(ni_root.firstpos);
+    StatePool sp(firstpos);
     while (!sp.empty()) {
       StateNode* sn = sp.pop();
       for (int i = n_symbols; i--; ) {
