@@ -13,8 +13,8 @@
  *     Gabor Szokoli, 2004
  *
  *  Last modified:
- *     $Date: 2009-01-20 23:44:27 +0100 (Tue, 20 Jan 2009) $ by $Author: schulte $
- *     $Revision: 8082 $
+ *     $Date: 2009-09-08 21:10:29 +0200 (Tue, 08 Sep 2009) $ by $Author: schulte $
+ *     $Revision: 9692 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -44,15 +44,15 @@
 namespace Gecode {
 
   /// Traits of SetVarArray
-  template <>
+  template<>
   class ArrayTraits<SetVarArray> {
   public:
-    typedef SetVarArgs   storage_type;
+    typedef SetVarArray  storage_type;
     typedef SetVar       value_type;
     typedef SetVarArgs   args_type;
   };
   /// Traits of SetVarArgs
-  template <>
+  template<>
   class ArrayTraits<SetVarArgs> {
   public:
     typedef SetVarArgs storage_type;
