@@ -9,8 +9,8 @@
  *     Christian Schulte, 2004
  *
  *  Last modified:
- *     $Date: 2009-02-03 11:13:22 +0100 (Tue, 03 Feb 2009) $ by $Author: schulte $
- *     $Revision: 8129 $
+ *     $Date: 2009-10-14 12:19:49 +0200 (Wed, 14 Oct 2009) $ by $Author: schulte $
+ *     $Revision: 9909 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -39,10 +39,10 @@
 
 namespace Gecode { namespace Set { namespace Element {
 
-  template <class SView, class RView>
+  template<class SView, class RView>
   forceinline
   ElementUnion<SView,RView>::
-  ElementUnion(Space& home, SView y0,
+  ElementUnion(Home home, SView y0,
                      IdxViewArray& iv0,
                      RView y1)
     : Propagator(home), x0(y0), iv(iv0), x1(y1) {
@@ -52,7 +52,7 @@ namespace Gecode { namespace Set { namespace Element {
     iv.subscribe(home,*this, PC_SET_ANY);
   }
 
-  template <class SView, class RView>
+  template<class SView, class RView>
   forceinline
   ElementUnion<SView,RView>::
   ElementUnion(Space& home, bool share,
@@ -63,13 +63,13 @@ namespace Gecode { namespace Set { namespace Element {
     iv.update(home,share,p.iv);
   }
 
-  template <class SView, class RView>
+  template<class SView, class RView>
   PropCost
   ElementUnion<SView,RView>::cost(const Space&, const ModEventDelta&) const {
     return PropCost::linear(PropCost::HI, iv.size()+2);
   }
 
-  template <class SView, class RView>
+  template<class SView, class RView>
   size_t
   ElementUnion<SView,RView>::dispose(Space& home) {
     home.ignore(*this,AP_DISPOSE);
@@ -82,10 +82,10 @@ namespace Gecode { namespace Set { namespace Element {
     return sizeof(*this);
   }
 
-  template <class SView, class RView>
+  template<class SView, class RView>
   ExecStatus
   ElementUnion<SView,RView>::
-  post(Space& home, SView x0, IdxViewArray& xs,
+  post(Home home, SView x0, IdxViewArray& xs,
        RView x1) {
     int n = xs.size();
 
@@ -97,13 +97,13 @@ namespace Gecode { namespace Set { namespace Element {
     return ES_OK;
   }
 
-  template <class SView, class RView>
+  template<class SView, class RView>
   Actor*
   ElementUnion<SView,RView>::copy(Space& home, bool share) {
     return new (home) ElementUnion<SView,RView>(home,share,*this);
   }
 
-  template <class SView, class RView>
+  template<class SView, class RView>
   ExecStatus
   ElementUnion<SView,RView>::propagate(Space& home, const ModEventDelta&) {
     Region r(home);
@@ -310,16 +310,16 @@ namespace Gecode { namespace Set { namespace Element {
         for (int i=n; i--;)
           is[i]=iv[i].view;
         GECODE_REWRITE(*this,(RelOp::UnionN<SView, SView>
-                        ::post(home,is,x0)));
+                        ::post(home(*this),is,x0)));
       } else if (ubsize == 2) {
         assert(n==2);
         SView a = iv[0].view;
         SView b = iv[1].view;
         GECODE_REWRITE(*this,(RelOp::Union<SView, SView, SView>
-                       ::post(home,a,b,x0)));
+                       ::post(home(*this),a,b,x0)));
       } else if (ubsize == 1) {
         assert(n==1);
-        GECODE_REWRITE(*this,(Rel::Eq<SView,SView>::post(home,x0,iv[0].view)));
+        GECODE_REWRITE(*this,(Rel::Eq<SView,SView>::post(home(*this),x0,iv[0].view)));
       } else {
         GECODE_ME_CHECK(x0.cardMax(home, 0));
         return ES_SUBSUMED(*this,home);
