@@ -9,8 +9,8 @@
  *     Christian Schulte, 2004
  *
  *  Last modified:
- *     $Date: 2009-02-03 11:13:22 +0100 (Tue, 03 Feb 2009) $ by $Author: schulte $
- *     $Revision: 8129 $
+ *     $Date: 2009-10-14 10:56:06 +0200 (Wed, 14 Oct 2009) $ by $Author: schulte $
+ *     $Revision: 9902 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -39,10 +39,10 @@
 
 namespace Gecode { namespace Set { namespace Element {
 
-  template <class SView, class RView>
+  template<class SView, class RView>
   forceinline
   ElementUnionConst<SView,RView>::
-  ElementUnionConst(Space& home, SView y0,
+  ElementUnionConst(Home home, SView y0,
                      SharedArray<IntSet>& iv0,
                      RView y1)
     : Propagator(home), x0(y0), iv(iv0), x1(y1) {
@@ -51,7 +51,7 @@ namespace Gecode { namespace Set { namespace Element {
     x1.subscribe(home,*this, PC_SET_ANY);
   }
 
-  template <class SView, class RView>
+  template<class SView, class RView>
   forceinline
   ElementUnionConst<SView,RView>::
   ElementUnionConst(Space& home, bool share,
@@ -62,13 +62,13 @@ namespace Gecode { namespace Set { namespace Element {
     iv.update(home,share,p.iv);
   }
 
-  template <class SView, class RView>
+  template<class SView, class RView>
   PropCost
   ElementUnionConst<SView,RView>::cost(const Space&, const ModEventDelta&) const {
     return PropCost::linear(PropCost::HI, iv.size()+2);
   }
 
-  template <class SView, class RView>
+  template<class SView, class RView>
   size_t
   ElementUnionConst<SView,RView>::dispose(Space& home) {
     home.ignore(*this,AP_DISPOSE);
@@ -81,10 +81,10 @@ namespace Gecode { namespace Set { namespace Element {
     return sizeof(*this);
   }
 
-  template <class SView, class RView>
+  template<class SView, class RView>
   ExecStatus
   ElementUnionConst<SView,RView>::
-  post(Space& home, SView x0, SharedArray<IntSet>& xs,
+  post(Home home, SView x0, SharedArray<IntSet>& xs,
        RView x1) {
     int n = xs.size();
 
@@ -96,13 +96,13 @@ namespace Gecode { namespace Set { namespace Element {
     return ES_OK;
   }
 
-  template <class SView, class RView>
+  template<class SView, class RView>
   Actor*
   ElementUnionConst<SView,RView>::copy(Space& home, bool share) {
     return new (home) ElementUnionConst<SView,RView>(home,share,*this);
   }
 
-  template <class SView, class RView>
+  template<class SView, class RView>
   ExecStatus
   ElementUnionConst<SView,RView>::propagate(Space& home, const ModEventDelta&) {
     Region r(home);
