@@ -9,8 +9,8 @@
  *     Christian Schulte, 2004
  *
  *  Last modified:
- *     $Date: 2009-02-03 11:13:22 +0100 (Tue, 03 Feb 2009) $ by $Author: schulte $
- *     $Revision: 8129 $
+ *     $Date: 2009-10-14 12:19:49 +0200 (Wed, 14 Oct 2009) $ by $Author: schulte $
+ *     $Revision: 9909 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -39,9 +39,9 @@
 
 namespace Gecode { namespace Set { namespace Rel {
 
-  template <class View0, class View1>
+  template<class View0, class View1>
   forceinline
-  ReSubset<View0,View1>::ReSubset(Space& home, View0 y0,
+  ReSubset<View0,View1>::ReSubset(Home home, View0 y0,
                                   View1 y1, Gecode::Int::BoolView y2)
     : Propagator(home), x0(y0), x1(y1), b(y2) {
     b.subscribe(home,*this, Gecode::Int::PC_INT_VAL);
@@ -49,7 +49,7 @@ namespace Gecode { namespace Set { namespace Rel {
     x1.subscribe(home,*this, PC_SET_ANY);
   }
 
-  template <class View0, class View1>
+  template<class View0, class View1>
   forceinline
   ReSubset<View0,View1>::ReSubset(Space& home, bool share, ReSubset& p)
     : Propagator(home,share,p) {
@@ -58,13 +58,13 @@ namespace Gecode { namespace Set { namespace Rel {
     b.update(home,share,p.b);
   }
 
-  template <class View0, class View1>
+  template<class View0, class View1>
   PropCost
   ReSubset<View0,View1>::cost(const Space&, const ModEventDelta&) const {
     return PropCost::ternary(PropCost::LO);
   }
 
-  template <class View0, class View1>
+  template<class View0, class View1>
   size_t
   ReSubset<View0,View1>::dispose(Space& home) {
     assert(!home.failed());
@@ -75,27 +75,27 @@ namespace Gecode { namespace Set { namespace Rel {
     return sizeof(*this);
   }
 
-  template <class View0, class View1>
+  template<class View0, class View1>
   ExecStatus
-  ReSubset<View0,View1>::post(Space& home, View0 x0, View1 x1,
+  ReSubset<View0,View1>::post(Home home, View0 x0, View1 x1,
                               Gecode::Int::BoolView b) {
     (void) new (home) ReSubset<View0,View1>(home,x0,x1,b);
     return ES_OK;
   }
 
-  template <class View0, class View1>
+  template<class View0, class View1>
   Actor*
   ReSubset<View0,View1>::copy(Space& home, bool share) {
     return new (home) ReSubset<View0,View1>(home,share,*this);
   }
 
-  template <class View0, class View1>
+  template<class View0, class View1>
   ExecStatus
   ReSubset<View0,View1>::propagate(Space& home, const ModEventDelta&) {
     if (b.one())
-      GECODE_REWRITE(*this,(Subset<View0,View1>::post(home,x0,x1)));
+      GECODE_REWRITE(*this,(Subset<View0,View1>::post(home(*this),x0,x1)));
     if (b.zero())
-      GECODE_REWRITE(*this,(NoSubset<View0,View1>::post(home,x0,x1)));
+      GECODE_REWRITE(*this,(NoSubset<View0,View1>::post(home(*this),x0,x1)));
 
     // check whether cardinalities still allow subset
     if (x0.cardMin() > x1.cardMax()) {
