@@ -7,8 +7,8 @@
 #     Guido Tack, 2006
 #
 #  Last modified:
-#     $Date: 2009-03-27 16:32:07 +0100 (Fri, 27 Mar 2009) $ by $Author: schulte $
-#     $Revision: 8593 $
+#     $Date: 2009-10-26 21:16:18 +0100 (Mon, 26 Oct 2009) $ by $Author: schulte $
+#     $Revision: 9990 $
 #
 #  This file is part of Gecode, the generic constraint
 #  development environment:
@@ -38,7 +38,7 @@
 set -e
 
 # List of file extensions for which properties should be set
-KEYWORDEXTS="cpp hpp hh sh perl ac in vsl vis"
+KEYWORDEXTS="cpp hpp hh sh perl ac in vsl vis mzn m4"
 
 for ext in ${KEYWORDEXTS}; do
     find . -name "*.$ext" ! -path './contribs/*' -prune \
@@ -46,36 +46,49 @@ for ext in ${KEYWORDEXTS}; do
 done
 
 # List of normal directories to set ignore properties on
-NORMALDIRS="int iter kernel minimodel search set support gist driver"
+GECODEDIRS="int iter kernel minimodel search set support gist driver graph scheduling flatzinc"
+TOOLSDIRS="flatzinc"
 
-for dir in ${NORMALDIRS}; do
+for dir in ${GECODEDIRS}; do
     find . -type d -path "./gecode/$dir*" \
     ! -path '*.svn*' \
     -exec svn propset svn:ignore -F misc/svn-ignore.txt '{}' \;
 done
+for dir in ${TOOLSDIRS}; do
+    find . -type d -path "./tools/$dir*" \
+    ! -path '*.svn*' \
+    -exec svn propset svn:ignore -F misc/svn-ignore.txt '{}' \;
+done
 
 svn propset svn:ignore -F misc/svn-ignore-root.txt '.'
 
-IGNORESUPPORT=`mktemp -t fixproperties`
+IGNORESUPPORT=`mktemp ignoresupportXXXX` || exit 1
 (echo config.hpp; svn propget svn:ignore './gecode/support') \
   > ${IGNORESUPPORT}
 svn propset svn:ignore -F ${IGNORESUPPORT} './gecode/support'
 rm -f ${IGNORESUPPORT}
 
 # Create list of executable examples, append it to svn-ignore.txt
-IGNOREEXAMPLES=`mktemp -t fixproperties` || exit 1
+IGNOREEXAMPLES=`mktemp ignoreexamplesXXXX` || exit 1
 (cat misc/svn-ignore.txt; \
   find "./examples" -name "*.cpp" | sed -e 's/\.cpp//g' | xargs -n1 basename) \
   > ${IGNOREEXAMPLES}
 svn propset svn:ignore -F ${IGNOREEXAMPLES} './examples'
 rm -f ${IGNOREEXAMPLES}
 
-find . -type d -path "./examples/*" \
-    ! -path '*.svn*' \
-    -exec svn propset svn:ignore -F misc/svn-ignore.txt '{}' \;
+# Create list of executable tools, append it to svn-ignore.txt
+TOOLSDIRS=`find tools -type d -and -not -path '*.svn*' -and -not -path 'tools'`
+for t in $TOOLSDIRS; do
+IGNORETOOLS=`mktemp ignoretoolsXXXX` || exit 1
+(cat misc/svn-ignore.txt; \
+  find "$t" -name "*.cpp" | sed -e 's/\.cpp//g' | xargs -n1 basename) \
+  > ${IGNORETOOLS}
+svn propset svn:ignore -F ${IGNORETOOLS} $t
+rm -f ${IGNORETOOLS}
+done
 
 # Append the test executable to svn-ignore.txt
-IGNORETEST=`mktemp -t fixproperties` || exit 1
+IGNORETEST=`mktemp ignoretestXXXX` || exit 1
 (cat misc/svn-ignore.txt; echo "test") > ${IGNORETEST}
 svn propset svn:ignore -F ${IGNORETEST} './test'
 rm -f ${IGNORETEST}
