@@ -7,8 +7,8 @@
  *     Christian Schulte, 2005
  *
  *  Last modified:
- *     $Date: 2009-01-20 23:44:27 +0100 (Tue, 20 Jan 2009) $ by $Author: schulte $
- *     $Revision: 8082 $
+ *     $Date: 2009-09-11 11:08:52 +0200 (Fri, 11 Sep 2009) $ by $Author: schulte $
+ *     $Revision: 9715 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -161,7 +161,8 @@ namespace Test { namespace Int {
          : Test("Linear::Bool::Int::"+
                 str(irt0)+"::"+s+"::"+str(a0.size())+"::"+str(c0),
                 a0.size(),0,1,true,Gecode::ICL_DEF),
-           a(a0), irt(irt0), c(c0) {}
+           a(a0), irt(irt0), c(c0) {
+       }
        /// Test whether \a x is solution
        virtual bool solution(const Assignment& x) const {
          double e = 0.0;
@@ -321,13 +322,17 @@ namespace Test { namespace Int {
            }
          }
          {
-           const int av1[10] = { 1, 1, 1, 1, 1, 1, 1, 1, 1, 1};
-           const int av2[10] = {-1,-1,-1,-1,-1,-1,-1,-1,-1,-1};
+           const int av1[10] = { 
+             1, 1, 1, 1, 1, 1, 1, 1, 1, 1
+           };
+           const int av2[10] = {
+             -1,-1,-1,-1,-1,-1,-1,-1,-1,-1
+           };
 
            for (int i=1; i<=10; i += 3) {
              IntArgs a1(i, av1);
              IntArgs a2(i, av2);
-             for (int c=0; c<=6; c += 3)
+             for (int c=0; c<=6; c++)
                for (IntRelTypes irts; irts(); ++irts) {
                  (void) new BoolInt("1",a1,irts.irt(),c);
                  (void) new BoolInt("2",a2,irts.irt(),-c);
@@ -338,14 +343,14 @@ namespace Test { namespace Int {
            IntArgs a4(5, -1,-2,-3,-4,-5);
            IntArgs a5(5, -1,-2,1,2,4);
 
-           for (int c=0; c<=16; c++)
-             for (IntRelTypes irts; irts(); ++irts) {
+           for (IntRelTypes irts; irts(); ++irts) {
+             for (int c=0; c<=16; c++) {
                (void) new BoolInt("3",a3,irts.irt(),c);
                (void) new BoolInt("4",a4,irts.irt(),-c);
                (void) new BoolInt("5",a5,irts.irt(),c);
                (void) new BoolInt("6",a5,irts.irt(),-c);
              }
-
+           }
 
            for (int i=1; i<=5; i += 2) {
              IntArgs a1(i, av1);
